@@ -10,7 +10,7 @@ set -e
 sleep 10 # (time to observe the failed tasks in the suite monitor).
 
 # Determine which family member(s) failed, if any
-FAILED_TASKS=$(cylc dump $CYLC_SUITE_REG_NAME | grep $CYLC_TASK_CYCLE_TIME | grep failed | sed -e 's/,.*$//')
+FAILED_TASKS=$(cylc dump $CYLC_SUITE_NAME | grep $CYLC_TASK_CYCLE_TIME | grep failed | sed -e 's/,.*$//')
 
 found_failed_member=false
 echo "FAILED TASKS:"
@@ -19,7 +19,7 @@ for T in $FAILED_TASKS; do
     if [[ $T == m_* ]]; then
         found_failed_member=true
         echo "REMOVING family member"
-        cylc control remove --force $CYLC_SUITE_REG_NAME ${T}.$CYLC_TASK_CYCLE_TIME
+        cylc control remove --force $CYLC_SUITE_NAME ${T}.$CYLC_TASK_CYCLE_TIME
     else
         echo "NOT REMOVING (not family member)"
     fi
