@@ -47,7 +47,6 @@ class AtCommandHandler(object):
     SHOULD_POLL_PROC_GROUP = True
     KILL_CMD_TMPL = "atrm '%(job_id)s'"
     POLL_CMD = "atq"
-    POLL_CMD_TMPL = POLL_CMD
     REC_ERR_FILTERS = [
         re.compile("warning: commands will be executed using /bin/sh")]
     REC_ID_FROM_SUBMIT_ERR = re.compile(r"\Ajob\s(?P<id>\S+)\sat")
@@ -90,7 +89,7 @@ class AtCommandHandler(object):
             for line in err.splitlines(True):
                 if self.REC_ID_FROM_SUBMIT_ERR.match(line):
                     out += line
-                elif any([rec.match(line) for rec in self.REC_ERR_FILTERS]):
+                elif any(rec.match(line) for rec in self.REC_ERR_FILTERS):
                     continue
                 elif line.strip() in self.ERR_NO_ATD_STRS:
                     raise OSError(
