@@ -21,7 +21,6 @@ import errno
 import os
 import re
 from subprocess import Popen, STDOUT
-import sys
 
 
 class BgCommandHandler(object):
@@ -33,7 +32,6 @@ class BgCommandHandler(object):
 
     SHOULD_KILL_PROC_GROUP = True
     POLL_CMD = "ps"
-    POLL_CMD_TMPL = POLL_CMD + " '%(job_id)s'"
     REC_ID_FROM_SUBMIT_OUT = re.compile(r"""\A(?P<id>\d+)\Z""")
 
     @classmethod
