@@ -27,7 +27,6 @@ class LoadlevelerHandler(object):
     DIRECTIVE_PREFIX = "# @ "
     KILL_CMD_TMPL = "llcancel '%(job_id)s'"
     POLL_CMD = "llq"
-    POLL_CMD_TMPL = POLL_CMD + " -f%%id '%(job_id)s'"
     REC_ID_FROM_SUBMIT_OUT = re.compile(
         r"""\Allsubmit:\sThe\sjob\s"(?P<id>[^"]+)"\s""")
     REC_ERR_FILTERS = [
@@ -72,7 +71,7 @@ class LoadlevelerHandler(object):
         new_err = ""
         if err:
             for line in err.splitlines():
-                if any([rec.match(line) for rec in self.REC_ERR_FILTERS]):
+                if any(rec.match(line) for rec in self.REC_ERR_FILTERS):
                     continue
                 new_err += line + "\n"
         return out, new_err
