@@ -32,7 +32,7 @@ batch_sys.filter_poll_output(out, job_id) => boolean
     * If this method is available, it will be called after the batch system's
       poll command is called and returns zero. The method should read the
       output to see if job_id is still alive in the batch system, and return
-      True if so. See also "batch_sys.POLL_CMD_TMPL".
+      True if so.
 
 batch_sys.filter_poll_many_output(out) => job_ids
     * Called after the batch system's poll many command. The method should read
@@ -82,13 +82,6 @@ batch_sys.KILL_CMD_TMPL
        and terminate a job ID. The command is formed using the logic:
            batch_sys.KILL_CMD_TMPL % {"job_id": job_id}
 
-batch_sys.POLL_CMD_TMPL
-    * A Python string template for getting the batch system command to
-      determine whether a job is alive, or to list jobs. The command is formed
-      using the logic:
-           batch_sys.POLL_CMD_TMPL % {"job_id": job_id}
-      See also "batch_sys.filter_poll_output".
-
 batch_sys.REC_ID_FROM_SUBMIT_ERR
 batch_sys.REC_ID_FROM_SUBMIT_OUT
     * A regular expression (compiled) to extract the job "id" from the standard
@@ -116,7 +109,6 @@ from subprocess import Popen, PIPE
 import sys
 import traceback
 from cylc.mkdir_p import mkdir_p
-from cylc.task_id import TaskID
 from cylc.task_message import TaskMessage
 from cylc.task_outputs import TASK_OUTPUT_SUCCEEDED
 from cylc.wallclock import get_current_time_string
