@@ -28,7 +28,7 @@ from parsec.validate import validator as vdr
 from parsec.validate import coercers
 from parsec import ParsecError
 from parsec.upgrade import upgrader, converter
-from cylc.owner import USER
+from cylc.suite_host import get_user
 from cylc.envvar import expandvars
 from cylc.mkdir_p import mkdir_p
 import cylc.flags
@@ -43,17 +43,17 @@ SPEC = {
     'process pool size': vdr(vtype='integer', default=4),
     'temporary directory': vdr(vtype='string'),
     'state dump rolling archive length': vdr(
-        vtype='integer', vmin=1, default=10),
+        vtype='integer', default=10),
     'disable interactive command prompts': vdr(vtype='boolean', default=True),
     'enable run directory housekeeping': vdr(vtype='boolean', default=False),
     'run directory rolling archive length': vdr(
-        vtype='integer', vmin=0, default=2),
+        vtype='integer', default=2),
     'task host select command timeout': vdr(
         vtype='interval', default=DurationFloat(10)),
     'task messaging': {
         'retry interval': vdr(
             vtype='interval', default=DurationFloat(5)),
-        'maximum number of tries': vdr(vtype='integer', vmin=1, default=7),
+        'maximum number of tries': vdr(vtype='integer', default=7),
         'connection timeout': vdr(
             vtype='interval', default=DurationFloat(30)),
     },
@@ -87,9 +87,8 @@ SPEC = {
 
     'suite logging': {
         'roll over at start-up': vdr(vtype='boolean', default=True),
-        'rolling archive length': vdr(vtype='integer', vmin=1, default=5),
-        'maximum size in bytes': vdr(
-            vtype='integer', vmin=1000, default=1000000),
+        'rolling archive length': vdr(vtype='integer', default=5),
+        'maximum size in bytes': vdr(vtype='integer', default=1000000),
     },
 
     'documentation': {
@@ -124,7 +123,7 @@ SPEC = {
 
     'communication': {
         'method': vdr(vtype='string', default="https",
-                      options=["https"]),
+                      options=["https", "http"]),
         'base port': vdr(vtype='integer', default=43001),
         'maximum number of ports': vdr(vtype='integer', default=100),
         'proxies on': vdr(vtype='boolean', default=False),
@@ -447,15 +446,17 @@ class GlobalConfig(config):
         return cls._DEFAULT
 
     def get_derived_host_item(
-            self, suite, item, host=None, owner=None, replace=False):
+            self, suite, item, host=None, owner=None, replace_home=False):
         """Compute hardwired paths relative to the configurable top dirs."""
 
         # suite run dir
         srdir = os.path.join(
-            self.get_host_item('run directory', host, owner, replace), suite)
+            self.get_host_item('run directory', host, owner, replace_home),
+            suite)
         # suite workspace
         swdir = os.path.join(
-            self.get_host_item('work directory', host, owner, replace), suite)
+            self.get_host_item('work directory', host, owner, replace_home),
+            suite)
 
         if item == 'suite run directory':
             value = srdir
@@ -483,7 +484,7 @@ class GlobalConfig(config):
 
         return value
 
-    def get_host_item(self, item, host=None, owner=None, replace=False):
+    def get_host_item(self, item, host=None, owner=None, replace_home=False):
         """This allows hosts with no matching entry in the config file
         to default to appropriately modified localhost settings."""
 
@@ -495,7 +496,7 @@ class GlobalConfig(config):
             # if no host is given the caller is asking about localhost
             host = 'localhost'
         if not owner:
-            owner = USER
+            owner = get_user()
 
         # is there a matching host section?
         host_key = None
@@ -510,7 +511,7 @@ class GlobalConfig(config):
                         host_key = cfg_host
                         break
         modify_dirs = False
-        if host_key:
+        if host_key is not None:
             # entry exists, any unset items under it have already
             # defaulted to modified localhost values (see site cfgspec)
             value = cfg['hosts'][host_key][item]
@@ -518,12 +519,15 @@ class GlobalConfig(config):
             # no entry so default to localhost and modify appropriately
             value = cfg['hosts']['localhost'][item]
             modify_dirs = True
-
-        if value and ('directory' in item) and (
-                modify_dirs or owner != USER or replace):
-            # replace local home dir with $HOME for evaluation on other host
-            value = value.replace(os.environ['HOME'], '$HOME')
-
+        if value is not None and 'directory' in item:
+            if replace_home or modify_dirs:
+                # Replace local home dir with $HOME for eval'n on other host.
+                value = value.replace(os.environ['HOME'], '$HOME')
+            elif owner != get_user():
+                # Replace with ~owner for direct access via local filesys
+                # (works for standard cylc-run directory location).
+                value = value.replace(
+                    os.environ['HOME'], os.path.expanduser('~%s' % owner))
         return value
 
     def roll_directory(self, d, name, archlen=0):
