@@ -22,21 +22,20 @@ import re
 from parsec.validate import validator as vdr
 from parsec.validate import (
     coercers, _strip_and_unquote, _strip_and_unquote_list, IllegalValueError)
-from parsec.util import itemstr
-from parsec.upgrade import upgrader, converter
+from parsec.upgrade import upgrader
 from parsec.config import config
 from isodatetime.dumpers import TimePointDumper
 from isodatetime.data import Calendar, TimePoint
 from isodatetime.parsers import TimePointParser, DurationParser
-from cylc.cycling.integer import REC_INTERVAL as REC_INTEGER_INTERVAL
 
 from cylc.cfgspec.utils import (
     coerce_interval, coerce_interval_list, DurationFloat)
 from cylc.cfgspec.globalcfg import GLOBAL_CFG
 from cylc.network import PRIVILEGE_LEVELS
+from cylc.task_id import TaskID
 
 
-REC_PARAM_INT_RANGE = re.compile('(\d+)\.\.(\d+)(?:\.\.(\d+))?')
+REC_PARAM_INT_RANGE = re.compile(r'\A(\d+)\.\.(\d+)(?:\.\.(\d+))?\Z')
 
 
 def _coerce_cycleinterval(value, keys, _):
@@ -139,21 +138,48 @@ def _coerce_final_cycletime(value, keys, _):
 
 
 def _coerce_parameter_list(value, keys, _):
-    """Coerce parameter list."""
-    value = _strip_and_unquote_list(keys, value)
-    # May be an integer range with step e.g. '1..6..2' (bounds inclusive).
-    try:
-        lower, upper, step = REC_PARAM_INT_RANGE.match(value[0]).groups()
-        step = step or 1
-    except AttributeError:
-        if '.' in value[0]:
-            # Dot is illegal in node names, probably bad range syntax.
-            raise IllegalValueError("parameter", keys, value)
-        return value
+    """Coerce parameter list
+
+    Can be:
+    * A list of str values. Each str value must conform to the same restriction
+      as a task name. Return list of str values.
+    * A mixture of int ranges and int values. Return list of str values
+      containing the sorted int list, zero-padded to the same width.
+
+    Raise IllegalValueError if:
+    * Mixing str and int range.
+    * A str value breaks the task name restriction.
+    """
+    items = []
+    can_only_be = None   # A flag to prevent mixing str and int range
+    for item in _strip_and_unquote_list(keys, value):
+        match = REC_PARAM_INT_RANGE.match(item)
+        if match:
+            if can_only_be == str:
+                raise IllegalValueError(
+                    'parameter', keys, value, 'mixing int range and str')
+            can_only_be = int
+            lower, upper, step = match.groups()
+            if not step:
+                step = 1
+            items.extend(range(int(lower), int(upper) + 1, int(step)))
+        elif TaskID.NAME_REC.match(item):
+            if not item.isdigit():
+                if can_only_be == int:
+                    raise IllegalValueError(
+                        'parameter', keys, value, 'mixing int range and str')
+                can_only_be = str
+            items.append(item)
+        else:
+            raise IllegalValueError(
+                'parameter', keys, value, '%s: bad value' % item)
+    if not items or can_only_be == str or any(
+            not str(item).isdigit() for item in items):
+        return items
     else:
-        n_dig = len(upper)
-        return [str(i).zfill(n_dig) for i in
-                range(int(lower), int(upper) + 1, int(step))]
+        items = [int(item) for item in items]
+        n_digits = len(str(max(items)))
+        return [str(item).zfill(n_digits) for item in sorted(items)]
 
 coercers['cycletime'] = _coerce_cycletime
 coercers['cycletime_format'] = _coerce_cycletime_format
@@ -166,10 +192,13 @@ coercers['parameter_list'] = _coerce_parameter_list
 
 
 SPEC = {
-    'title': vdr(vtype='string', default=""),
-    'description': vdr(vtype='string', default=""),
     'group': vdr(vtype='string', default="(ungrouped)"),
-    'URL': vdr(vtype='string', default=""),
+    'meta': {
+        'title': vdr(vtype='string', default=""),
+        'description': vdr(vtype='string', default=""),
+        'URL': vdr(vtype='string', default=""),
+        '__MANY__': vdr(vtype='string', default=""),
+    },
     'cylc': {
         'UTC mode': vdr(
             vtype='boolean', default=GLOBAL_CFG.get(['cylc', 'UTC mode'])),
@@ -304,9 +333,6 @@ SPEC = {
     'runtime': {
         '__MANY__': {
             'inherit': vdr(vtype='string_list', default=[]),
-            'title': vdr(vtype='string', default=""),
-            'description': vdr(vtype='string', default=""),
-            'URL': vdr(vtype='string', default=""),
             'init-script': vdr(vtype='string', default=""),
             'env-script': vdr(vtype='string', default=""),
             'err-script': vdr(vtype='string', default=""),
@@ -316,6 +342,12 @@ SPEC = {
             'extra log files': vdr(vtype='string_list', default=[]),
             'enable resurrection': vdr(vtype='boolean', default=False),
             'work sub-directory': vdr(vtype='string'),
+            'meta': {
+                'title': vdr(vtype='string', default=""),
+                'description': vdr(vtype='string', default=""),
+                'URL': vdr(vtype='string', default=""),
+                '__MANY__': vdr(vtype='string', default=""),
+            },
             'simulation': {
                 'default run length': vdr(vtype='interval', default='PT10S'),
                 'speedup factor': vdr(vtype='float', default=None),
@@ -372,6 +404,7 @@ SPEC = {
                 'failed handler': vdr(vtype='string_list'),
                 'submission failed handler': vdr(vtype='string_list'),
                 'warning handler': vdr(vtype='string_list'),
+                'critical handler': vdr(vtype='string_list'),
                 'retry handler': vdr(vtype='string_list'),
                 'submission retry handler': vdr(vtype='string_list'),
                 'execution timeout handler': vdr(vtype='string_list'),
@@ -486,6 +519,30 @@ def upg(cfg, descr):
         '6.11.0',
         ['runtime', '__MANY__', 'execution polling intervals'],
         ['runtime', '__MANY__', 'job', 'execution polling intervals'])
+    u.deprecate(
+        '7.5.0',
+        ['runtime', '__MANY__', 'title'],
+        ['runtime', '__MANY__', 'meta', 'title'])
+    u.deprecate(
+        '7.5.0',
+        ['runtime', '__MANY__', 'description'],
+        ['runtime', '__MANY__', 'meta', 'description'])
+    u.deprecate(
+        '7.5.0',
+        ['runtime', '__MANY__', 'URL'],
+        ['runtime', '__MANY__', 'meta', 'URL'])
+    u.deprecate(
+        '7.5.0',
+        ['title'],
+        ['meta', 'title'])
+    u.deprecate(
+        '7.5.0',
+        ['description'],
+        ['meta', 'description'])
+    u.deprecate(
+        '7.5.0',
+        ['URL'],
+        ['meta', 'URL'])
     u.obsolete('7.2.2', ['cylc', 'dummy mode'])
     u.obsolete('7.2.2', ['cylc', 'simulation mode'])
     u.obsolete('7.2.2', ['runtime', '__MANY__', 'dummy mode'])
