@@ -18,8 +18,6 @@
 
 """This module provides base classes for cycling data objects."""
 
-import unittest
-
 from abc import ABCMeta, abstractmethod, abstractproperty
 
 
@@ -32,9 +30,12 @@ def parse_exclusion(expr):
                         "permitted" % expr)
     else:
         remainder, exclusions = expr.split('!')
-        if '/' in exclusions:
-            raise Exception("'%s': exclusion must be at the end of the "
-                            "expression" % expr)
+        if ',' in exclusions:
+            if (not exclusions.strip().startswith('(') or not
+                    exclusions.strip().endswith(')')):
+                raise Exception("'%s': a list of exclusions must be "
+                                "enclosed in parentheses." % exclusions)
+
         exclusions = exclusions.translate(None, ' ()')
         exclusions = exclusions.split(',')
         return remainder.strip(), exclusions
@@ -101,6 +102,8 @@ class PointBase(object):
     _TYPE = None
     _TYPE_SORT_KEY = None
 
+    __slots__ = ('value')
+
     @abstractproperty
     def TYPE(self):
         return self._TYPE
@@ -200,6 +203,8 @@ class IntervalBase(object):
     _TYPE = None
     _TYPE_SORT_KEY = None
 
+    __slots__ = ('value')
+
     @abstractproperty
     def TYPE(self):
         return self._TYPE
@@ -324,6 +329,8 @@ class SequenceBase(object):
     _TYPE = None
     _TYPE_SORT_KEY = None
 
+    __slots__ = ()
+
     @abstractproperty
     def TYPE(self):
         return self._TYPE
@@ -409,17 +416,107 @@ class SequenceBase(object):
         pass
 
 
-class TestBaseClasses(unittest.TestCase):
-    """Test the abstract base classes cannot be instantiated on their own
-    """
-    def test_simple_abstract_class_test(self):
-        """Cannot instantiate abstract classes, they must be defined in
-        the subclasses"""
-        self.assertRaises(TypeError, SequenceBase, "sequence-string",
-                          "context_string")
-        self.assertRaises(TypeError, IntervalBase, "value")
-        self.assertRaises(TypeError, PointBase, "value")
+class ExclusionBase(object):
+    """A collection of points or sequences that are treated in an
+    exclusionary manner"""
+
+    __metaclass__ = ABCMeta
+    __slots__ = ('exclusion_sequences', 'exclusion_points',
+                 'exclusion_start_point', 'exclusion_end_point')
+
+    def __init__(self, start_point, end_point=None):
+        """creates an exclusions object that can contain integer points
+        or integer sequences to be used as excluded points."""
+        self.exclusion_sequences = []
+        self.exclusion_points = []
+        self.exclusion_start_point = start_point
+        self.exclusion_end_point = end_point
+
+    @abstractmethod
+    def build_exclusions(self):
+        """Constructs the set of exclusion sequences or points"""
+        pass
+
+    def __contains__(self, point):
+        """Checks to see if the Exclusions object contains a point
+        in any of the exclusion sequences.
+
+        Args:
+            point (str): The time point to check lies in the
+                ISO8601Sequence object.
+        """
+        if point in self.exclusion_points:
+            return True
+        if any(seq.is_valid(point) for seq in self.exclusion_sequences):
+            return True
+        return False
+
+    def __getitem__(self, key):
+        """Allows indexing of the exclusion object"""
+        return self.exclusion_sequences[key]
+
+    def __str__(self):
+        returns = []
+        for point in sorted(self.exclusion_points):
+            returns.append(str(point))
+        for sequence in self.exclusion_sequences:
+            returns.append(str(sequence))
+        ret = ','.join(returns)
+        if ',' in ret:
+            ret = '(' + ret + ')'
+        return ret
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
+    import unittest
+
+    class TestBaseClasses(unittest.TestCase):
+        """Test the abstract base classes cannot be instantiated on their own
+        """
+        def test_simple_abstract_class_test(self):
+            """Cannot instantiate abstract classes, they must be defined in
+            the subclasses"""
+            self.assertRaises(TypeError, SequenceBase, "sequence-string",
+                              "context_string")
+            self.assertRaises(TypeError, IntervalBase, "value")
+            self.assertRaises(TypeError, PointBase, "value")
+
+    class TestParseExclusion(unittest.TestCase):
+        """Test cases for the parser function"""
+        def test_parse_exclusion_simple(self):
+            """Tests the simple case of exclusion parsing"""
+            expression = "PT1H!20000101T02Z"
+            sequence, exclusion = parse_exclusion(expression)
+
+            self.assertEqual(sequence, "PT1H")
+            self.assertEqual(exclusion, ['20000101T02Z'])
+
+        def test_parse_exclusions_list(self):
+            """Tests the simple case of exclusion parsing"""
+            expression = "PT1H!(T03, T06, T09)"
+            sequence, exclusion = parse_exclusion(expression)
+
+            self.assertEqual(sequence, "PT1H")
+            self.assertEqual(exclusion, ['T03', 'T06', 'T09'])
+
+        def test_parse_exclusions_list_spaces(self):
+            """Tests the simple case of exclusion parsing"""
+            expression = "PT1H!    (T03, T06,   T09)   "
+            sequence, exclusion = parse_exclusion(expression)
+
+            self.assertEqual(sequence, "PT1H")
+            self.assertEqual(exclusion, ['T03', 'T06', 'T09'])
+
+        def test_parse_bad_exclusion(self):
+            """Tests incorrectly formatted exclusions"""
+            expression1 = "T01/PT1H!(T06, T09), PT5M"
+            expression2 = "T01/PT1H!T03, PT17H, (T06, T09), PT5M"
+            expression3 = "T01/PT1H! PT8H, (T06, T09)"
+            expression4 = "T01/PT1H! T03, T06, T09"
+
+            self.assertRaises(Exception, parse_exclusion, expression1)
+            self.assertRaises(Exception, parse_exclusion, expression2)
+            self.assertRaises(Exception, parse_exclusion, expression3)
+            self.assertRaises(Exception, parse_exclusion, expression4)
+
     unittest.main()
