@@ -28,7 +28,7 @@ from isodatetime.timezone import (
     get_local_time_zone, get_local_time_zone_format)
 from cylc.time_parser import CylcTimeParser
 from cylc.cycling import (
-    PointBase, IntervalBase, SequenceBase, PointParsingError,
+    PointBase, IntervalBase, SequenceBase, ExclusionBase, PointParsingError,
     IntervalParsingError, SequenceDegenerateError)
 from parsec.validate import IllegalValueError
 
@@ -54,6 +54,7 @@ class SuiteSpecifics(object):
     abbrev_util = None
     interval_parser = None
     point_parser = None
+    iso8601_parsers = None
 
 
 def memoize(function):
@@ -89,6 +90,8 @@ class ISO8601Point(PointBase):
     TYPE = CYCLER_TYPE_ISO8601
     TYPE_SORT_KEY = CYCLER_TYPE_SORT_KEY_ISO8601
 
+    __slots__ = ('value')
+
     @classmethod
     def from_nonstandard_string(cls, point_string):
         """Standardise a date-time string."""
@@ -173,6 +176,8 @@ class ISO8601Interval(IntervalBase):
     TYPE = CYCLER_TYPE_ISO8601
     TYPE_SORT_KEY = CYCLER_TYPE_SORT_KEY_ISO8601
 
+    __slots__ = ('value')
+
     @classmethod
     def get_null(cls):
         """Return a null interval."""
@@ -281,14 +286,53 @@ class ISO8601Interval(IntervalBase):
         return bool(interval)
 
 
+class ISO8601Exclusions(ExclusionBase):
+    """A collection of ISO8601Sequences that represent excluded sequences.
+
+    The object is able to determine if points are within any of its
+    grouped exclusion sequences. The Python ``in`` and ``not in`` operators
+    may be used on this object to determine if a point is in the collection
+    of exclusion sequences."""
+
+    __slots__ = ExclusionBase.__slots__ + ('p_iso_exclusions',)
+
+    def __init__(self, excl_points, start_point, end_point=None):
+        super(ISO8601Exclusions, self).__init__(start_point, end_point)
+        self.p_iso_exclusions = []
+        self.build_exclusions(excl_points)
+
+    def build_exclusions(self, excl_points):
+        for point in excl_points:
+            try:
+                # Try making an ISO8601Point
+                exclusion_point = ISO8601Point.from_nonstandard_string(
+                    str(point)) if point else None
+                if exclusion_point not in self.exclusion_points:
+                    self.exclusion_points.append(exclusion_point)
+                    self.p_iso_exclusions.append(str(exclusion_point))
+            except (AttributeError, TypeError, ValueError):
+                # Try making an ISO8601Sequence
+                exclusion = ISO8601Sequence(point, self.exclusion_start_point,
+                                            self.exclusion_end_point)
+                self.exclusion_sequences.append(exclusion)
+
+
 class ISO8601Sequence(SequenceBase):
 
-    """A sequence of ISO8601 date time points separated by an interval."""
+    """A sequence of ISO8601 date time points separated by an interval.
+    Note that an ISO8601Sequence object (may) contain
+    ISO8601ExclusionSequences"""
 
     TYPE = CYCLER_TYPE_ISO8601
     TYPE_SORT_KEY = CYCLER_TYPE_SORT_KEY_ISO8601
     _MAX_CACHED_POINTS = 100
 
+    __slots__ = ('dep_section', 'context_start_point', 'context_end_point',
+                 'offset', '_cached_first_point_values',
+                 '_cached_next_point_values', '_cached_valid_point_booleans',
+                 '_cached_recent_valid_points', 'spec', 'abbrev_util',
+                 'recurrence', 'exclusions', 'step', 'value')
+
     @classmethod
     def get_async_expr(cls, start_point=None):
         """Express a one-off sequence at the initial cycle point."""
@@ -302,11 +346,16 @@ class ISO8601Sequence(SequenceBase):
 
         if context_start_point is None:
             self.context_start_point = context_start_point
+        elif isinstance(context_start_point, ISO8601Point):
+            self.context_start_point = context_start_point
         else:
             self.context_start_point = ISO8601Point.from_nonstandard_string(
                 context_start_point)
+
         if context_end_point is None:
             self.context_end_point = None
+        elif isinstance(context_end_point, ISO8601Point):
+            self.context_end_point = context_end_point
         else:
             self.context_end_point = ISO8601Point.from_nonstandard_string(
                 context_end_point)
@@ -319,30 +368,38 @@ class ISO8601Sequence(SequenceBase):
         self._cached_recent_valid_points = []
 
         self.spec = dep_section
-        self.abbrev_util = CylcTimeParser(
-            self.context_start_point, self.context_end_point,
-            num_expanded_year_digits=SuiteSpecifics.NUM_EXPANDED_YEAR_DIGITS,
-            dump_format=SuiteSpecifics.DUMP_FORMAT,
-            assumed_time_zone=SuiteSpecifics.ASSUMED_TIME_ZONE
-        )
-
+        self.abbrev_util = CylcTimeParser(self.context_start_point,
+                                          self.context_end_point,
+                                          SuiteSpecifics.iso8601_parsers)
         # Parse_recurrence returns an isodatetime TimeRecurrence object
         # and a list of exclusion strings.
         self.recurrence, excl_points = self.abbrev_util.parse_recurrence(
-            dep_section)  # should this be self.dep_section??
+            dep_section)
+
+        # Determine the exclusion start point and end point
+        try:
+            exclusion_start_point = ISO8601Point.from_nonstandard_string(
+                str(self.recurrence.start_point))
+        except ValueError:
+            exclusion_start_point = self.context_start_point
+
+        try:
+            exclusion_end_point = ISO8601Point.from_nonstandard_string(
+                str(self.recurrence.end_point))
+        except ValueError:
+            exclusion_end_point = self.context_end_point
 
-        # Convert (potentially) non-standard strings to ISO8601Point objects.
         self.exclusions = []
-        for point in excl_points:
-            exclusion = ISO8601Point.from_nonstandard_string(
-                str(point)) if point else None
-            self.exclusions.append(exclusion)
 
-        # Convert the exclusion ISO8601Points to TimePoints so they can
-        # be compared with the TimeRecurrence object later.
-        self.p_iso_exclusions = []
-        for timepoint in self.exclusions:
-            self.p_iso_exclusions.append(point_parse(str(timepoint)))
+        # Creating an exclusions object instead
+        if excl_points:
+            try:
+                self.exclusions = ISO8601Exclusions(
+                    excl_points,
+                    exclusion_start_point,
+                    exclusion_end_point)
+            except AttributeError:
+                pass
 
         self.step = ISO8601Interval(str(self.recurrence.duration))
         self.value = str(self.recurrence)
@@ -377,6 +434,7 @@ class ISO8601Sequence(SequenceBase):
         # Iterate starting at recent valid points, for speed.
         if self.exclusions and point in self.exclusions:
             return False
+
         for valid_point in reversed(self._cached_recent_valid_points):
             if valid_point == point:
                 return True
@@ -431,8 +489,11 @@ class ISO8601Sequence(SequenceBase):
 
         for recurrence_iso_point in self.recurrence:
             # Is recurrence point greater than aribitrary point?
-            if (recurrence_iso_point > p_iso_point or
-                    (recurrence_iso_point in self.p_iso_exclusions)):
+            if (
+                    recurrence_iso_point > p_iso_point or
+                    (self.exclusions and
+                     recurrence_iso_point in self.exclusions.p_iso_exclusions)
+            ):
                 break
             prev_iso_point = recurrence_iso_point
         if prev_iso_point is None:
@@ -648,13 +709,17 @@ def init(num_expanded_year_digits=0, custom_dump_format=None, time_zone=None,
         dump_format=SuiteSpecifics.DUMP_FORMAT,
         assumed_time_zone=time_zone_hours_minutes
     )
-    SuiteSpecifics.abbrev_util = CylcTimeParser(
-        None, None,
-        num_expanded_year_digits=SuiteSpecifics.NUM_EXPANDED_YEAR_DIGITS,
+
+    SuiteSpecifics.iso8601_parsers = CylcTimeParser.initiate_parsers(
         dump_format=SuiteSpecifics.DUMP_FORMAT,
+        num_expanded_year_digits=num_expanded_year_digits,
         assumed_time_zone=SuiteSpecifics.ASSUMED_TIME_ZONE
     )
 
+    SuiteSpecifics.abbrev_util = CylcTimeParser(
+        None, None, SuiteSpecifics.iso8601_parsers
+    )
+
 
 def get_point_relative(offset_string, base_point):
     """Create a point from offset_string applied to base_point."""
@@ -738,6 +803,23 @@ class TestISO8601Sequence(unittest.TestCase):
         self.assertEqual(output, ['20000101T0000Z', '20000101T0100Z',
                                   '20000101T0300Z', '20000101T0400Z'])
 
+    def test_exclusions_offset(self):
+        """Test the generation of points for sequences with exclusions
+        that have an offset on the end"""
+        init(time_zone='Z')
+        sequence = ISO8601Sequence('PT1H!20000101T00Z+PT1H', '20000101T00Z')
+
+        output = []
+        point = sequence.get_start_point()
+        count = 0
+        while point and count < 4:
+            output.append(point)
+            point = sequence.get_next_point(point)
+            count += 1
+        output = [str(out) for out in output]
+        self.assertEqual(output, ['20000101T0000Z', '20000101T0200Z',
+                                  '20000101T0300Z', '20000101T0400Z'])
+
     def test_multiple_exclusions_complex1(self):
         """Tests sequences that have multiple exclusions and a more
         complicated format"""
@@ -802,27 +884,315 @@ class TestISO8601Sequence(unittest.TestCase):
         self.assertEqual(output, ['20000101T0000Z', '20000101T0100Z',
                                   '20000101T0400Z', '20000101T0500Z'])
 
-    def test_exclusions_extensive(self):
+    def test_advanced_exclusions_partial_datetime1(self):
+        """Advanced exclusions refers to exclusions that are not just
+        simple points but could be time periods or recurrences such as
+        '!T06' or similar"""
+        init(time_zone='Z')
+        # Run 3-hourly but not at 06:00 (from the ICP)
+        sequence = ISO8601Sequence('PT3H!T06', '20000101T00Z')
+
+        output = []
+        point = sequence.get_start_point()
+        count = 0
+        # We are going to make ten sequence points
+        while point and count < 10:
+            output.append(point)
+            point = sequence.get_next_point(point)
+            count += 1
+        output = [str(out) for out in output]
+        # We should expect every T06 to be excluded
+        self.assertEqual(output, ['20000101T0000Z', '20000101T0300Z',
+                                  '20000101T0900Z', '20000101T1200Z',
+                                  '20000101T1500Z', '20000101T1800Z',
+                                  '20000101T2100Z', '20000102T0000Z',
+                                  '20000102T0300Z', '20000102T0900Z'])
+
+    def test_advanced_exclusions_partial_datetime2(self):
+        """Advanced exclusions refers to exclusions that are not just
+        simple points but could be time periods or recurrences such as
+        '!T06' or similar"""
+        init(time_zone='Z')
+        # Run hourly but not at 00:00, 06:00, 12:00, 18:00
+        sequence = ISO8601Sequence('T-00!(T00, T06, T12, T18)', '20000101T00Z')
+
+        output = []
+        point = sequence.get_start_point()
+        count = 0
+        # We are going to make 18 sequence points
+        while point and count < 18:
+            output.append(point)
+            point = sequence.get_next_point(point)
+            count += 1
+        output = [str(out) for out in output]
+        # We should expect T00, T06, T12, and T18 to be excluded
+        self.assertEqual(output, ['20000101T0100Z', '20000101T0200Z',
+                                  '20000101T0300Z', '20000101T0400Z',
+                                  '20000101T0500Z', '20000101T0700Z',
+                                  '20000101T0800Z', '20000101T0900Z',
+                                  '20000101T1000Z', '20000101T1100Z',
+                                  '20000101T1300Z', '20000101T1400Z',
+                                  '20000101T1500Z', '20000101T1600Z',
+                                  '20000101T1700Z', '20000101T1900Z',
+                                  '20000101T2000Z', '20000101T2100Z'])
+
+    def test_advanced_exclusions_partial_datetime3(self):
+        """Advanced exclusions refers to exclusions that are not just
+        simple points but could be time periods or recurrences such as
+        '!T06' or similar"""
+        init(time_zone='Z')
+        # Run 5 minutely but not at 15 minutes past the hour from ICP
+        sequence = ISO8601Sequence('PT5M!T-15', '20000101T00Z')
+
+        output = []
+        point = sequence.get_start_point()
+        count = 0
+        # We are going to make 15 sequence points
+        while point and count < 15:
+            output.append(point)
+            point = sequence.get_next_point(point)
+            count += 1
+        output = [str(out) for out in output]
+        # We should expect xx:15 (15 minutes past the hour) to be excluded
+        self.assertEqual(output, ['20000101T0000Z', '20000101T0005Z',
+                                  '20000101T0010Z',
+                                  '20000101T0020Z', '20000101T0025Z',
+                                  '20000101T0030Z', '20000101T0035Z',
+                                  '20000101T0040Z', '20000101T0045Z',
+                                  '20000101T0050Z', '20000101T0055Z',
+                                  '20000101T0100Z', '20000101T0105Z',
+                                  '20000101T0110Z', '20000101T0120Z'])
+
+    def test_advanced_exclusions_partial_datetime4(self):
+        """Advanced exclusions refers to exclusions that are not just
+        simple points but could be time periods or recurrences such as
+        '!T06' or similar"""
+        init(time_zone='Z')
+        # Run daily at 00:00 except on Mondays
+        sequence = ISO8601Sequence('T00!W-1T00', '20170422T00Z')
+
+        output = []
+        point = sequence.get_start_point()
+        count = 0
+        # We are going to make 19 sequence points
+        while point and count < 9:
+            output.append(point)
+            point = sequence.get_next_point(point)
+            count += 1
+        output = [str(out) for out in output]
+        # We should expect Monday 24th April and Monday 1st May
+        # to be excluded.
+        self.assertEqual(output, ['20170422T0000Z', '20170423T0000Z',
+                                  '20170425T0000Z', '20170426T0000Z',
+                                  '20170427T0000Z', '20170428T0000Z',
+                                  '20170429T0000Z', '20170430T0000Z',
+                                  '20170502T0000Z'])
+
+    def test_exclusions_to_string(self):
+        init(time_zone='Z')
+        # Chack that exclusions are not included where they should not be.
+        basic = ISO8601Sequence('PT1H', '2000', '2001')
+        self.assertFalse('!' in str(basic))
+
+        # Check that exclusions are parsable.
+        sequence = ISO8601Sequence('PT1H!(20000101T10Z, PT6H)', '2000', '2001')
+        sequence2 = ISO8601Sequence(str(sequence), '2000', '2001')
+        self.assertEqual(sequence, sequence2)
+
+    def test_advanced_exclusions_sequences1(self):
+        """Advanced exclusions refers to exclusions that are not just
+        simple points but could be time periods or recurrences such as
+        '!T06' or similar"""
+        init(time_zone='Z')
+        # Run hourly from the ICP but not 3-hourly
+        sequence = ISO8601Sequence('PT1H!PT3H', '20000101T01Z')
+
+        output = []
+        point = sequence.get_start_point()
+        count = 0
+        # We are going to make six sequence points
+        while point and count < 6:
+            output.append(point)
+            point = sequence.get_next_point(point)
+            count += 1
+        output = [str(out) for out in output]
+        # We should expect to see hourly from ICP but not 3 hourly
+        self.assertEqual(output, ['20000101T0200Z', '20000101T0300Z',
+                                  '20000101T0500Z', '20000101T0600Z',
+                                  '20000101T0800Z', '20000101T0900Z'])
+
+    def test_advanced_exclusions_sequences2(self):
+        """Advanced exclusions refers to exclusions that are not just
+        simple points but could be time periods or recurrences such as
+        '!T06' or similar"""
+        init(time_zone='Z')
+        # Run hourly on the hour but not 3 hourly on the hour
+        sequence = ISO8601Sequence('T-00!T-00/PT3H', '20000101T00Z')
+
+        output = []
+        point = sequence.get_start_point()
+        count = 0
+        # We are going to make six sequence points
+        while point and count < 6:
+            output.append(point)
+            point = sequence.get_next_point(point)
+            count += 1
+        output = [str(out) for out in output]
+
+        self.assertEqual(output, ['20000101T0100Z', '20000101T0200Z',
+                                  '20000101T0400Z', '20000101T0500Z',
+                                  '20000101T0700Z', '20000101T0800Z'])
+
+    def test_advanced_exclusions_sequences3(self):
+        """Advanced exclusions refers to exclusions that are not just
+        simple points but could be time periods or recurrences such as
+        '!T06' or similar"""
+        init(time_zone='Z')
+        # Run daily at 12:00 except every 3rd day
+        sequence = ISO8601Sequence('T12!P3D', '20000101T12Z')
+
+        output = []
+        point = sequence.get_start_point()
+        count = 0
+        # We are going to make six sequence points
+        while point and count < 6:
+            output.append(point)
+            point = sequence.get_next_point(point)
+            count += 1
+        output = [str(out) for out in output]
+
+        self.assertEqual(output, ['20000102T1200Z', '20000103T1200Z',
+                                  '20000105T1200Z', '20000106T1200Z',
+                                  '20000108T1200Z', '20000109T1200Z'])
+
+    def test_advanced_exclusions_sequences4(self):
+        """Advanced exclusions refers to exclusions that are not just
+        simple points but could be time periods or recurrences such as
+        '!T06' or similar"""
+        init(time_zone='Z')
+        # Run every hour from 01:00 excluding every 3rd hour.
+        sequence = ISO8601Sequence('T01/PT1H!+PT3H/PT3H', '20000101T01Z')
+
+        output = []
+        point = sequence.get_start_point()
+        count = 0
+        # We are going to make six sequence points
+        while point and count < 6:
+            output.append(point)
+            point = sequence.get_next_point(point)
+            count += 1
+        output = [str(out) for out in output]
+
+        self.assertEqual(output, ['20000101T0100Z', '20000101T0200Z',
+                                  '20000101T0300Z', '20000101T0500Z',
+                                  '20000101T0600Z', '20000101T0800Z'])
+
+    def test_advanced_exclusions_sequences5(self):
+        """Advanced exclusions refers to exclusions that are not just
+        simple points but could be time periods or recurrences such as
+        '!T06' or similar"""
+        init(time_zone='Z')
+        # Run every hour from 01:00 excluding every 3rd hour.
+        sequence = ISO8601Sequence('T-00 ! 2000', '20000101T00Z')
+
+        output = []
+        point = sequence.get_start_point()
+        count = 0
+        # We are going to make six sequence points
+        while point and count < 6:
+            output.append(point)
+            point = sequence.get_next_point(point)
+            count += 1
+        output = [str(out) for out in output]
+
+        self.assertEqual(output, ['20000101T0100Z', '20000101T0200Z',
+                                  '20000101T0300Z', '20000101T0400Z',
+                                  '20000101T0500Z', '20000101T0600Z'])
+
+    def test_advanced_exclusions_sequences_mix_points_sequences(self):
+        """Advanced exclusions refers to exclusions that are not just
+        simple points but could be time periods or recurrences such as
+        '!T06' or similar"""
+        init(time_zone='Z')
+        # Run every hour from 01:00 excluding every 3rd hour.
+        sequence = ISO8601Sequence('T-00 ! (2000, PT2H)', '20000101T00Z')
+
+        output = []
+        point = sequence.get_start_point()
+        count = 0
+        # We are going to make six sequence points
+        while point and count < 6:
+            output.append(point)
+            point = sequence.get_next_point(point)
+            count += 1
+        output = [str(out) for out in output]
+
+        self.assertEqual(output, ['20000101T0100Z', '20000101T0300Z',
+                                  '20000101T0500Z', '20000101T0700Z',
+                                  '20000101T0900Z', '20000101T1100Z'])
+
+    def test_advanced_exclusions_sequences_implied_start_point(self):
+        """Advanced exclusions refers to exclusions that are not just
+        simple points but could be time periods or recurrences such as
+        '!T06' or similar"""
+        init(time_zone='Z')
+        # Run every hour from 01:00 excluding every 3rd hour.
+        sequence = ISO8601Sequence('T05/PT1H!PT3H', '20000101T00Z')
+
+        output = []
+        point = sequence.get_start_point()
+        count = 0
+        # We are going to make six sequence points
+        while point and count < 6:
+            output.append(point)
+            point = sequence.get_next_point(point)
+            count += 1
+        output = [str(out) for out in output]
+
+        self.assertEqual(output, ['20000101T0600Z', '20000101T0700Z',
+                                  '20000101T0900Z', '20000101T1000Z',
+                                  '20000101T1200Z', '20000101T1300Z'])
+
+    def test_exclusions_sequences_points(self):
         """Test ISO8601Sequence methods for sequences with exclusions"""
-        init(time_zone='+05')
-        sequence = ISO8601Sequence('PT1H!20000101T02Z', '20000101T00Z',
-                                   '20000101T05Z')
+        init(time_zone='Z')
+        # Run every hour from 01:00 excluding every 3rd hour
+        sequence = ISO8601Sequence('T01/PT1H!PT3H', '20000101T01Z')
 
         point_0 = ISO8601Point('20000101T00Z')
         point_1 = ISO8601Point('20000101T01Z')
-        point_2 = ISO8601Point('20000101T02Z')  # The excluded point.
+        point_2 = ISO8601Point('20000101T02Z')
         point_3 = ISO8601Point('20000101T03Z')
+        point_4 = ISO8601Point('20000101T04Z')
+
+        self.assertFalse(point_0 in sequence.exclusions)
+        self.assertTrue(point_1 in sequence.exclusions)
+        self.assertTrue(sequence.is_on_sequence(point_2))
+        self.assertTrue(sequence.is_on_sequence(point_3))
+        self.assertFalse(sequence.is_on_sequence(point_4))
+        self.assertTrue(point_4 in sequence.exclusions)
+
+    def test_exclusions_extensive(self):
+        """Test ISO8601Sequence methods for sequences with exclusions"""
+        init(time_zone='+05')
+        sequence = ISO8601Sequence('PT1H!20000101T02+05', '20000101T00',
+                                   '20000101T05')
+
+        point_0 = ISO8601Point('20000101T0000+05')
+        point_1 = ISO8601Point('20000101T0100+05')
+        point_2 = ISO8601Point('20000101T0200+05')  # The excluded point.
+        point_3 = ISO8601Point('20000101T0300+05')
 
         self.assertFalse(sequence.is_on_sequence(point_2))
         self.assertFalse(sequence.is_valid(point_2))
         self.assertEqual(sequence.get_prev_point(point_2), point_1)
         self.assertEqual(sequence.get_prev_point(point_3), point_1)
-        self.assertEqual(sequence.get_nearest_prev_point(point_2), point_1)
+        self.assertEqual(sequence.get_prev_point(point_2), point_1)
         self.assertEqual(sequence.get_nearest_prev_point(point_3), point_1)
         self.assertEqual(sequence.get_next_point(point_1), point_3)
         self.assertEqual(sequence.get_next_point(point_2), point_3)
 
-        sequence = ISO8601Sequence('PT1H!20000101T00Z', '20000101T00Z')
+        sequence = ISO8601Sequence('PT1H!20000101T00+05', '20000101T00+05')
         self.assertEqual(sequence.get_first_point(point_0), point_1)
         self.assertEqual(sequence.get_start_point(), point_1)
 
@@ -830,15 +1200,15 @@ class TestISO8601Sequence(unittest.TestCase):
         """Test ISO8601Sequence methods for sequences with multiple exclusions
         """
         init(time_zone='+05')
-        sequence = ISO8601Sequence('PT1H!(20000101T02Z,20000101T03Z)',
-                                   '20000101T00Z',
-                                   '20000101T06Z')
+        sequence = ISO8601Sequence('PT1H!(20000101T02,20000101T03)',
+                                   '20000101T00',
+                                   '20000101T06')
 
-        point_0 = ISO8601Point('20000101T00Z')
-        point_1 = ISO8601Point('20000101T01Z')
-        point_2 = ISO8601Point('20000101T02Z')  # First excluded point
-        point_3 = ISO8601Point('20000101T03Z')  # Second excluded point
-        point_4 = ISO8601Point('20000101T04Z')
+        point_0 = ISO8601Point('20000101T0000+05')
+        point_1 = ISO8601Point('20000101T0100+05')
+        point_2 = ISO8601Point('20000101T0200+05')  # First excluded point
+        point_3 = ISO8601Point('20000101T0300+05')  # Second excluded point
+        point_4 = ISO8601Point('20000101T0400+05')
 
         # Check the excluded points are not on the sequence
         self.assertFalse(sequence.is_on_sequence(point_2))
@@ -849,12 +1219,12 @@ class TestISO8601Sequence(unittest.TestCase):
         self.assertEqual(sequence.get_prev_point(point_2), point_1)
         # Should skip two excluded points
         self.assertEqual(sequence.get_prev_point(point_4), point_1)
-        self.assertEqual(sequence.get_nearest_prev_point(point_2), point_1)
+        self.assertEqual(sequence.get_prev_point(point_2), point_1)
         self.assertEqual(sequence.get_nearest_prev_point(point_4), point_1)
         self.assertEqual(sequence.get_next_point(point_1), point_4)
         self.assertEqual(sequence.get_next_point(point_3), point_4)
 
-        sequence = ISO8601Sequence('PT1H!20000101T00Z', '20000101T00Z')
+        sequence = ISO8601Sequence('PT1H!20000101T00+05', '20000101T00')
         # Check that the first point is after 00.
         self.assertEqual(sequence.get_first_point(point_0), point_1)
         self.assertEqual(sequence.get_start_point(), point_1)
@@ -862,12 +1232,12 @@ class TestISO8601Sequence(unittest.TestCase):
         # Check a longer list of exclusions
         # Also note you can change the format of the exclusion list
         # (removing the parentheses)
-        sequence = ISO8601Sequence('PT1H! 20000101T02Z, 20000101T03Z,'
-                                   '20000101T04Z',
-                                   '20000101T00Z',
-                                   '20000101T06Z')
-        self.assertEqual(sequence.get_nearest_prev_point(point_3), point_1)
-        self.assertEqual(sequence.get_nearest_prev_point(point_4), point_1)
+        sequence = ISO8601Sequence('PT1H!(20000101T02+05, 20000101T03+05,'
+                                   '20000101T04+05)',
+                                   '20000101T00',
+                                   '20000101T06')
+        self.assertEqual(sequence.get_prev_point(point_3), point_1)
+        self.assertEqual(sequence.get_prev_point(point_4), point_1)
 
     def test_simple(self):
         """Run some simple tests for date-time cycling."""
