@@ -1,4 +1,4 @@
-#!/usr/bin/env
+#!/usr/bin/env python
 
 # THIS FILE IS PART OF THE CYLC SUITE ENGINE.
 # Copyright (C) 2008-2017 NIWA
@@ -19,13 +19,12 @@
 import gtk
 import os
 import re
-import sys
 import xdot
 from cylc.config import SuiteConfig
-from cylc.graphing import CGraphPlain
+from cylc.cycling.loader import get_point
+from cylc.graphing import CGraphPlain, CGraph
 from cylc.gui import util
 from cylc.task_id import TaskID
-from cylc.templatevars import load_template_vars
 from cylc.suite_logging import ERR
 
 """
@@ -34,6 +33,13 @@ TODO - factor more commonality out of MyDotWindow, MyDotWindow2
 """
 
 
+def style_ghost_node(node):
+    """Apply default style to a ghost node."""
+    node.attr['color'] = '#888888'
+    node.attr['fontcolor'] = '#888888'
+    node.attr['fillcolor'] = '#eeeeee'  # Used when style=filled.
+
+
 class CylcDotViewerCommon(xdot.DotWindow):
     def load_config(self):
         if self.suiterc:
@@ -384,15 +390,38 @@ class MyDotWindow(CylcDotViewerCommon):
     def ungroup_all(self, w):
         self.get_graph(ungroup_all=True)
 
-    def get_graph(self, group_nodes=[], ungroup_nodes=[],
+    def is_ghost_task(self, name, point, cache=None):
+        """Returns True if the task <name> at cycle point <point> is a ghost.
+        """
+        try:
+            sequences = self.suiterc.taskdefs[name].sequences
+        except KeyError:
+            # Handle tasks not used in the graph.
+            return False
+        if not sequences:
+            return False
+        for sequence in sequences:
+            p_str = str(point)
+            if (cache and sequence in cache and p_str in cache[sequence]):
+                if cache[sequence][p_str]:
+                    return False
+            else:
+                temp = sequence.is_on_sequence(get_point(point))
+                if cache is not None:
+                    cache.setdefault(sequence, {})[p_str] = temp
+                if temp:
+                    return False
+        return True
+
+    def get_graph(self, group_nodes=None, ungroup_nodes=None,
                   ungroup_recursive=False, ungroup_all=False, group_all=False):
         if not self.suiterc:
             return
-        family_nodes = self.suiterc.get_first_parent_descendants().keys()
-        suite_polling_tasks = self.suiterc.suite_polling_tasks
+        family_nodes = self.suiterc.get_first_parent_descendants()
         # Note this is used by "cylc graph" but not gcylc.
         # self.start_ and self.stop_point_string come from CLI.
-        graph = self.suiterc.get_graph(
+        graph = CGraph.get_graph(
+            self.suiterc,
             group_nodes=group_nodes,
             ungroup_nodes=ungroup_nodes,
             ungroup_recursive=ungroup_recursive,
@@ -402,10 +431,18 @@ class MyDotWindow(CylcDotViewerCommon):
 
         graph.graph_attr['rankdir'] = self.orientation
 
-        for node in graph.nodes():
-            name, point_string = TaskID.split(node.get_name())
+        # Style nodes.
+        cache = {}  # For caching is_on_sequence() calls.
+        for node in graph.iternodes():
+            name, point = TaskID.split(node.get_name())
             if name in family_nodes:
+                # Style family nodes.
                 node.attr['shape'] = 'doubleoctagon'
+                # Detecting ghost families would involve analysing triggers
+                # in the suite's graphing.
+            elif self.is_ghost_task(name, point, cache=cache):
+                # Style ghost nodes.
+                style_ghost_node(node)
 
         self.graph = graph
         self.filter_graph()
