@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 # THIS FILE IS PART OF THE CYLC SUITE ENGINE.
-# Copyright (C) 2008-2016 NIWA
+# Copyright (C) 2008-2017 NIWA
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,8 +29,3 @@ class CylcError(Exception):
 
     def __str__(self):
         return repr(self.msg)
-
-
-class PortFileError(CylcError):
-    """Error reading a port file."""
-    pass
