@@ -17,10 +17,9 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import re
-import sys
 import unittest
-from copy import copy
 from cylc.param_expand import GraphExpander
+from cylc.task_id import TaskID
 
 """Module for parsing cylc graph strings."""
 
@@ -97,35 +96,42 @@ class GraphParser(object):
     LEN_FAM_TRIG_EXT_ALL = len(FAM_TRIG_EXT_ALL)
     LEN_FAM_TRIG_EXT_ANY = len(FAM_TRIG_EXT_ANY)
 
+    _RE_NODE = r'(?:!)?' + TaskID.NAME_RE
+    _RE_PARAMS = r'<[\w,=\-+]+>'
+    _RE_OFFSET = r'\[[\w\-\+\^:]+\]'
+    _RE_TRIG = r':[\w\-]+'
+
     # Match fully qualified parameterized single nodes.
     REC_NODE_FULL = re.compile(r'''
         (
-        (?:(?:!)?\w[\w\-+%@]*)  # node name
-        (?:<[\w,=\-+]+>)?       # optional parameter list
-        (?:\[[\w\-\+\^:]+\])?   # optional cycle point offset
-        (?::[\w\-]+)?           # optional trigger type
+        (?:''' + _RE_NODE + r''')    # node name
+        (?:''' + _RE_PARAMS + r''')? # optional parameter list
+        (?:''' + _RE_OFFSET + r''')? # optional cycle point offset
+        (?:''' + _RE_TRIG + r''')?   # optional trigger type
         )
     ''', re.X)           # end of string
 
     # Extract node info from a left-side expression, after parameter expansion.
     REC_NODES = re.compile(r'''
-        ((?:!)?\w[\w\-+%@]*)  # node name
-        (\[[\w\-\+\^:]+\])?   # optional cycle point offset
-        (:[\w\-]+)?           # optional trigger type
+        (''' + _RE_NODE + r''')      # node name
+        (''' + _RE_OFFSET + r''')?   # optional cycle point offset
+        (''' + _RE_TRIG + r''')?     # optional trigger type
     ''', re.X)
 
     REC_TRIG_QUAL = re.compile(r'''
-        (?:(?:!)?\w[\w\-+%@]*)   # node name (ignore)
-        (:[\w\-]+)?              # optional trigger type
+        (?:''' + _RE_NODE + r''')    # node name (ignore)
+        (''' + _RE_TRIG + r''')?     # optional trigger type
     ''', re.X)
 
     REC_COMMENT = re.compile('#.*$')
 
     # Detect presence of expansion parameters in a graph line.
-    REC_PARAMETERS = re.compile(r'<[\w,=\-+]+>')
+    REC_PARAMS = re.compile(_RE_PARAMS)
 
     # Detect and extract suite state polling task info.
-    REC_SUITE_STATE = re.compile('(\w+)(<([\w\.\-/]+)::(\w+)(:\w+)?>)')
+    REC_SUITE_STATE = re.compile(
+        r'(' + TaskID.NAME_RE + ')(<([\w\.\-/]+)::(' + TaskID.NAME_RE + ')(' +
+        _RE_TRIG + ')?>)')
 
     def __init__(self, family_map=None, parameters=None):
         """Initializing the graph string parser.
@@ -140,9 +146,8 @@ class GraphParser(object):
         self.triggers = {}
         self.original = {}
         self.suite_state_polling_tasks = {}
-        self.r1_point = None
 
-    def parse_graph(self, graph_string, r1_point=None):
+    def parse_graph(self, graph_string):
         """Parse the graph string for a single graph section.
 
         (Assumes any general line-continuation markers have been processed).
@@ -155,8 +160,6 @@ class GraphParser(object):
               i. Replace families with members (any or all semantics).
              ii. Record parsed dependency information for each right-side node.
         """
-        self.r1_point = r1_point
-
         # Strip comments, whitespace, and blank lines.
         non_blank_lines = []
         for line in graph_string.split('\n'):
@@ -240,7 +243,7 @@ class GraphParser(object):
         line_set = set()
         graph_expander = GraphExpander(self.parameters)
         for line in full_lines:
-            if not self.__class__.REC_PARAMETERS.search(line):
+            if not self.__class__.REC_PARAMS.search(line):
                 line_set.add(line)
                 continue
             for l in graph_expander.expand(line):
@@ -389,70 +392,42 @@ class GraphParser(object):
                 n_info += m_info
             else:
                 n_info += [(name, offset, trig)]
-        info = n_info
+        self._add_trigger(expr, rights, n_expr, n_info)
 
-        for right in rights:
-            if right.startswith(self.__class__.SUICIDE_MARK):
-                right = right[1:]
-                suicide = True
-            else:
-                suicide = False
-            if right in self.family_map:
-                for mem in self.family_map[right]:
-                    self._add_trigger(expr, mem, n_expr, info, suicide)
-            else:
-                self._add_trigger(expr, right, n_expr, info, suicide)
-
-        self._tidy_triggers()
-
-    def _add_trigger(self, orig_expr, right, expr, info, suicide):
-        """Store trigger info from "expr => right" for a single task ('right').
+    def _add_trigger(self, orig_expr, rights, expr, info):
+        """Store trigger info from "expr => right".
 
         Arg info is [(name, offset, trigger_type)] for each name in expr.
-
         """
         trigs = []
         for name, offset, trigger in info:
             # Replace finish triggers (must be done after member substn).
             if trigger == self.__class__.TRIG_FINISH:
-                this = "%s%s%s" % (name, re.escape(offset), trigger)
+                this = "%s%s%s" % (name, offset, trigger)
                 that = "(%s%s%s%s%s%s%s)" % (
                     name, offset, self.__class__.TRIG_SUCCEED,
                     self.__class__.OP_OR,
                     name, offset, self.__class__.TRIG_FAIL)
-                expr = re.sub(this, that, expr)
+                expr = expr.replace(this, that)
                 trigs += [
                     "%s%s%s" % (name, offset, self.__class__.TRIG_SUCCEED),
                     "%s%s%s" % (name, offset, self.__class__.TRIG_FAIL)]
             else:
-                this = "%s%s%s" % (name, re.escape(offset), trigger)
-                that = "%s%s%s" % (name, offset, trigger)
-                expr = re.sub(this, that, expr)
                 trigs += ["%s%s%s" % (name, offset, trigger)]
-        if right not in self.triggers:
-            self.triggers[right] = {}
-            self.original[right] = {}
-        self.triggers[right][expr] = (trigs, suicide)
-        self.original[right][expr] = orig_expr
 
-    def _tidy_triggers(self):
-        """Remove any null triggers for tasks that also have non-null triggers.
-
-        (Null triggers are only needed for initial or lone nodes.)
-        """
-        # NOT USED, but leaving this here for reference.
-        # Extra null triggers have no adverse effect, but this method has a big
-        # negative performance impact on the dev/suites/busy.
-        return
-
-        clean_me = set()
-        for right, val in self.triggers.items():
-            exprs = val.keys()
-            if len(exprs) > 1:
-                if '' in exprs:
-                    clean_me.add(right)
-        for right in clean_me:
-            del self.triggers[right]['']
+        for right in rights:
+            suicide = right.startswith(self.__class__.SUICIDE_MARK)
+            if suicide:
+                right = right[1:]
+            if right in self.family_map:
+                members = self.family_map[right]
+            else:
+                members = [right]
+            for member in members:
+                self.triggers.setdefault(member, {})
+                self.original.setdefault(member, {})
+                self.triggers[member][expr] = (trigs, suicide)
+                self.original[member][expr] = orig_expr
 
     def print_triggers(self):
         for right, val in self.triggers.items():
