@@ -19,13 +19,10 @@
 """Cylc suite graphing module. Modules relying on this should test for
 ImportError due to pygraphviz/graphviz not being installed."""
 
-import re
 import pygraphviz
-from cylc.task_id import TaskID
-from cycling.loader import get_point, get_point_relative, get_interval
-from graphnode import graphnode
 
-# TODO: Do we still need autoURL below?
+from cylc.cycling.loader import get_point, get_point_relative
+from cylc.task_id import TaskID
 
 
 class CGraphPlain(pygraphviz.AGraph):
@@ -41,7 +38,7 @@ class CGraphPlain(pygraphviz.AGraph):
 
     def node_attr_by_taskname(self, node_string):
         try:
-            name, point_string = TaskID.split(node_string)
+            name = TaskID.split(node_string)[0]
         except ValueError:
             # Special node?
             if node_string.startswith("__remove_"):
@@ -55,7 +52,7 @@ class CGraphPlain(pygraphviz.AGraph):
     def style_edge(self, left, right):
         pass
 
-    def style_node(self, node_string, autoURL, base=False):
+    def style_node(self, node_string):
         node = self.get_node(node_string)
         try:
             name, point_string = TaskID.split(node_string)
@@ -71,30 +68,7 @@ class CGraphPlain(pygraphviz.AGraph):
             label += "\\n" + self.suite_polling_tasks[name][3]
         label += "\\n" + point_string
         node.attr['label'] = label
-        if autoURL:
-            if base:
-                # TODO - This is only called from cylc_add_edge in this
-                # base class ... should it also be called from add_node?
-                node.attr['URL'] = 'base:' + node_string
-            else:
-                node.attr['URL'] = node_string
-
-    def cylc_add_node(self, node_string, autoURL, **attr):
-        pygraphviz.AGraph.add_node(self, node_string, **attr)
-        self.style_node(node_string, autoURL)
-
-    def cylc_add_edge(self, left, right, autoURL, **attr):
-        if left is None and right is None:
-            pass
-        elif left is None:
-            self.cylc_add_node(right, autoURL)
-        elif right is None:
-            self.cylc_add_node(left, autoURL)
-        else:
-            pygraphviz.AGraph.add_edge(self, left, right, **attr)
-            self.style_node(left, autoURL, base=True)
-            self.style_node(right, autoURL, base=True)
-            self.style_edge(left, right)
+        node.attr['URL'] = node_string
 
     def cylc_remove_nodes_from(self, nodes):
         """Remove nodes, returning extra edge structure if possible.
@@ -107,7 +81,6 @@ class CGraphPlain(pygraphviz.AGraph):
         if not nodes:
             return
         existing_nodes = set(self.nodes())
-        add_edges = set()
         remove_nodes = set(nodes)
         remove_node_groups = {}
         groups = {}
@@ -195,7 +168,7 @@ class CGraphPlain(pygraphviz.AGraph):
         # Create a new node name for the group.
         names = set()
         index = -1
-        for group, group_nodes in sorted(groups.items()):
+        for group in sorted(groups):
             index += 1
             name = "__remove_%s__" % index
             while name in existing_nodes or name in names:
@@ -221,39 +194,36 @@ class CGraphPlain(pygraphviz.AGraph):
             new_edges.add((l_node, new_r_node, True, False, False))
 
         self.remove_nodes_from(nodes)
-        self.add_edges(list(new_edges))
+        self.add_edges(sorted(new_edges))
 
     def add_edges(self, edges, ignore_suicide=False):
-        edges.sort()  # TODO: does sorting help layout stability?
-        for edge in edges:
+        """Add edges and nodes connected by the edges."""
+        for edge in sorted(edges):
             left, right, skipped, suicide, conditional = edge
-            if suicide and ignore_suicide:
+            if left is None and right is None or suicide and ignore_suicide:
                 continue
-            attrs = {}
-            if conditional:
-                if suicide:
-                    attrs['style'] = 'dashed'
-                    attrs['arrowhead'] = 'odot'
-                else:
-                    attrs['style'] = 'solid'
-                    attrs['arrowhead'] = 'onormal'
+            if left is None:
+                pygraphviz.AGraph.add_node(self, right)
+                self.style_node(right)
+            elif right is None:
+                pygraphviz.AGraph.add_node(self, left)
+                self.style_node(left)
             else:
-                if suicide:
-                    attrs['style'] = 'dashed'
-                    attrs['arrowhead'] = 'dot'
+                attrs = {'penwidth': 2}
+                if skipped:
+                    attrs.update({'style': 'dotted', 'arrowhead': 'oinv'})
+                elif conditional and suicide:
+                    attrs.update({'style': 'dashed', 'arrowhead': 'odot'})
+                elif conditional:
+                    attrs.update({'style': 'solid', 'arrowhead': 'onormal'})
+                elif suicide:
+                    attrs.update({'style': 'dashed', 'arrowhead': 'dot'})
                 else:
-                    attrs['style'] = 'solid'
-                    attrs['arrowhead'] = 'normal'
-            if skipped:
-                # override
-                attrs['style'] = 'dotted'
-                attrs['arrowhead'] = 'oinv'
-
-            attrs['penwidth'] = 2
-
-            self.cylc_add_edge(
-                left, right, True, **attrs
-            )
+                    attrs.update({'style': 'solid', 'arrowhead': 'normal'})
+                pygraphviz.AGraph.add_edge(self, left, right, **attrs)
+                self.style_node(left)
+                self.style_node(right)
+                self.style_edge(left, right)
 
     def add_cycle_point_subgraphs(self, edges):
         """Draw nodes within cycle point groups (subgraphs)."""
@@ -314,11 +284,11 @@ class CGraph(CGraphPlain):
         # graph attributes
         # - default node attributes
         for item in vizconfig['default node attributes']:
-            attr, value = re.split('\s*=\s*', item)
+            attr, value = [val.strip() for val in item.split('=', 1)]
             self.node_attr[attr] = value
         # - default edge attributes
         for item in vizconfig['default edge attributes']:
-            attr, value = re.split('\s*=\s*', item)
+            attr, value = [val.strip() for val in item.split('=', 1)]
             self.edge_attr[attr] = value
 
         # non-default node attributes by task name
@@ -341,12 +311,12 @@ class CGraph(CGraphPlain):
                         self.task_attr[item] = []
                     self.task_attr[item].append(attr)
 
-    def style_node(self, node_string, autoURL, base=False):
-        super(self.__class__, self).style_node(
-            node_string, autoURL, False)
+    def style_node(self, node_string):
+        super(self.__class__, self).style_node(node_string)
         node = self.get_node(node_string)
+        node.attr['shape'] = 'ellipse'  # Default shape.
         for item in self.node_attr_by_taskname(node_string):
-            attr, value = re.split('\s*=\s*', item)
+            attr, value = [val.strip() for val in item.split('=', 1)]
             node.attr[attr] = value
         if self.vizconfig['use node color for labels']:
             node.attr['fontcolor'] = node.attr['color']
@@ -363,39 +333,46 @@ class CGraph(CGraphPlain):
                 edge.attr['color'] = left_node.attr['fillcolor']
         edge.attr['penwidth'] = self.vizconfig['edge penwidth']
 
+    @classmethod
+    def get_graph(
+            cls, suiterc, group_nodes=None, ungroup_nodes=None,
+            ungroup_recursive=False, group_all=False, ungroup_all=False,
+            ignore_suicide=False, subgraphs_on=False):
+        """Return dependency graph."""
+        # Use visualization settings.
+        start_point_string = (
+            suiterc.cfg['visualization']['initial cycle point'])
 
-class edge(object):
-    def __init__(self, left, right, sequence, suicide=False,
-                 conditional=False):
-        """contains qualified node names, e.g. 'foo[T-6]:out1'"""
-        self.left = left
-        self.right = right
-        self.suicide = suicide
-        self.sequence = sequence
-        self.conditional = conditional
+        # Use visualization settings in absence of final cycle point definition
+        # when not validating (stops slowdown of validation due to vis
+        # settings)
+        stop_point = None
+        vfcp = suiterc.cfg['visualization']['final cycle point']
+        if vfcp:
+            try:
+                stop_point = get_point_relative(
+                    vfcp, get_point(start_point_string)).standardise()
+            except ValueError:
+                stop_point = get_point(vfcp).standardise()
 
-    def get_right(self, inpoint, start_point):
-        inpoint_string = str(inpoint)
-        if self.right is None:
-            return None
-
-        # strip off special outputs
-        self.right = re.sub(':\w+', '', self.right)
-
-        return TaskID.get(self.right, inpoint_string)
-
-    def get_left(self, inpoint, start_point, base_interval):
-        # strip off special outputs
-        left = re.sub(':[\w-]+', '', self.left)
-
-        left_graphnode = graphnode(left, base_interval=base_interval)
-        if left_graphnode.offset_is_from_ict:
-            point = get_point_relative(left_graphnode.offset_string,
-                                       start_point)
-        elif left_graphnode.offset_string:
-            point = get_point_relative(left_graphnode.offset_string, inpoint)
+        if stop_point is not None:
+            if stop_point < get_point(start_point_string):
+                # Avoid a null graph.
+                stop_point_string = start_point_string
+            else:
+                stop_point_string = str(stop_point)
         else:
-            point = inpoint
-        name = left_graphnode.name
+            stop_point_string = None
 
-        return TaskID.get(name, point)
+        graph = cls(
+            suiterc.suite,
+            suiterc.suite_polling_tasks,
+            suiterc.cfg['visualization'])
+        gr_edges = suiterc.get_graph_raw(
+            start_point_string, stop_point_string,
+            group_nodes, ungroup_nodes, ungroup_recursive,
+            group_all, ungroup_all)
+        graph.add_edges(gr_edges, ignore_suicide)
+        if subgraphs_on:
+            graph.add_cycle_point_subgraphs(gr_edges)
+        return graph
