@@ -31,14 +31,13 @@ from cylc.cfgspec.globalcfg import GLOBAL_CFG
 from cylc.cfgspec.gcylc import gcfg
 from cylc.cfgspec.gscan import gsfg
 import cylc.flags
-from cylc.gui.app_gcylc import run_get_stdout
 from cylc.gui.dot_maker import DotMaker
 from cylc.gui.scanutil import (KEY_PORT, get_gpanel_scan_menu,
                                update_suites_info)
 from cylc.gui.util import get_icon, setup_icons
 from cylc.network import KEY_STATES
 from cylc.network.suite_state_client import extract_group_state
-from cylc.owner import USER
+from cylc.suite_host import get_user
 
 
 class ScanPanelApplet(object):
@@ -125,7 +124,7 @@ class ScanPanelAppletUpdater(object):
         self.dots = DotMaker(self.theme)
         self.suite_info_map = {}
         self._set_exception_hook()
-        self.owner_pattern = re.compile(r'\A%s\Z' % USER)
+        self.owner_pattern = re.compile(r'\A%s\Z' % get_user())
 
     def clear_stopped_suites(self):
         """Clear stopped suite information that may have built up."""
@@ -275,13 +274,12 @@ class ScanPanelAppletUpdater(object):
     def _add_image_box(self, suite_host_info_tuples):
         image_eb = gtk.EventBox()
         image_eb.show()
-        is_all_stopped = False
         running_status_list = []
         status_list = []
         suite_keys = []
         for info_tuple in suite_host_info_tuples:
-            suite, host, status, task_states, is_stopped = info_tuple
-            suite_keys.append((host, USER, suite))
+            suite, host, status, _, is_stopped = info_tuple
+            suite_keys.append((host, get_user(), suite))
             if not is_stopped:
                 running_status_list.append(status)
             status_list.append(status)
