@@ -38,7 +38,7 @@ from cylc.gui.scanutil import (
 from cylc.gui.util import get_icon, setup_icons, set_exception_hook_dialog
 from cylc.network import (
     KEY_GROUP, KEY_STATES, KEY_TASKS_BY_STATE, KEY_TITLE, KEY_UPDATE_TIME)
-from cylc.owner import USER
+from cylc.suite_host import get_user
 from cylc.task_state import (
     TASK_STATUSES_ORDERED, TASK_STATUS_RUNAHEAD, TASK_STATUS_FAILED,
     TASK_STATUS_SUBMIT_FAILED)
@@ -74,7 +74,8 @@ class ScanApp(object):
         self.window = gtk.Window()
         title = "cylc gscan"
         for opt, items, skip in [
-                ("-n", patterns_name, None), ("-o", patterns_owner, USER)]:
+                ("-n", patterns_name, None),
+                ("-o", patterns_owner, get_user())]:
             if items:
                 for pattern in items:
                     if pattern != skip:
@@ -109,10 +110,10 @@ class ScanApp(object):
         if gsfg.COL_SUITE not in vis_cols:
             vis_cols.append(gsfg.COL_SUITE.lower())
         # In multiple host environment, add host column by default
-        if hosts:
+        if hosts != ['localhost']:
             vis_cols.append(gsfg.COL_HOST.lower())
         # In multiple owner environment, add owner column by default
-        if patterns_owner != [USER]:
+        if patterns_owner != [get_user()]:
             vis_cols.append(gsfg.COL_OWNER.lower())
         # Construct the group, host, owner, suite, title, update time column.
         for col_title, col_id, col_cell_text_setter in [
@@ -343,8 +344,8 @@ class ScanApp(object):
         hosts_item.set_image(img)
         hosts_item.show()
         hosts_item.connect(
-            "button-press-event",
-            lambda b, e: launch_hosts_dialog(
+            "activate",
+            lambda w: launch_hosts_dialog(
                 self.hosts, self.updater.set_hosts))
         view_menu.append(hosts_item)
 
@@ -440,7 +441,7 @@ class ScanApp(object):
         if event.button == 1:
             if not pth:
                 return False
-            path, column, cell_x, _ = pth
+            path, column, cell_x = pth[:3]
             if column.get_title() == gsfg.COL_STATUS:
                 dot_offset, dot_width = tuple(column.cell_get_position(
                     column.get_cell_renderers()[1]))
@@ -534,8 +535,7 @@ class ScanApp(object):
             self._prev_tooltip_location_id = None
             return False
         x, y = self.treeview.convert_widget_to_bin_window_coords(x, y)
-        path, column, cell_x, _ = (
-            self.treeview.get_path_at_pos(x, y))
+        path, column, cell_x = (self.treeview.get_path_at_pos(x, y))[:3]
         model = self.treeview.get_model()
         iter_ = model.get_iter(path)
         parent_iter = model.iter_parent(iter_)
