@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 # THIS FILE IS PART OF THE CYLC SUITE ENGINE.
-# Copyright (C) 2008-2016 NIWA
+# Copyright (C) 2008-2017 NIWA
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -79,8 +79,7 @@ class Tailer(threading.Thread):
                 owner, host = user_at_host.split("@", 1)
             else:
                 owner, host = (None, user_at_host)
-            ssh = str(GLOBAL_CFG.get_host_item(
-                "remote shell template", host, owner)).replace(" %s", "")
+            ssh = str(GLOBAL_CFG.get_host_item("ssh command", host, owner))
             command = shlex.split(ssh) + ["-n", user_at_host]
             cmd_tmpl = str(GLOBAL_CFG.get_host_item(
                 "remote tail command template", host, owner))
