@@ -228,7 +228,7 @@ class TreeUpdater(threading.Thread):
                 tkeys = ['submitted_time_string', 'started_time_string',
                          'finished_time_string']
 
-                if id in self.fam_state_summary:
+                if is_fam:
                     # Family timing currently left empty.
                     for dt in tkeys:
                         t_info[dt] = ""
@@ -240,24 +240,7 @@ class TreeUpdater(threading.Thread):
                     tetc_string = None
 
                     for dt in tkeys:
-                        try:
-                            t_info[dt] = summary[id][dt]
-                        except KeyError:
-                            # Pre cylc-6 back compat: no special "_string"
-                            # items, and the data was in string form already.
-                            odt = dt.replace("_string", "")
-                            try:
-                                t_info[dt] = summary[id][odt]
-                            except KeyError:
-                                if dt == 'finished_time_string':
-                                    # Was succeeded_time.
-                                    t_info[dt] = summary[id].get(
-                                        'succeeded_time')
-                                else:
-                                    t_info[dt] = None
-                            if isinstance(t_info[dt], str):
-                                # Remove decimal fraction seconds.
-                                t_info[dt] = t_info[dt].split('.')[0]
+                        t_info[dt] = summary[id][dt]
 
                     # Compute percent progress.
                     if (isinstance(tstart, float) and (
@@ -318,8 +301,7 @@ class TreeUpdater(threading.Thread):
                         t_info['finished_time_string'] = "%s?" % (
                             t_info['finished_time_string'])
 
-                # Use "*" (or "" for family rows) until slot is populated
-                # and for pre cylc-6 back compat for host and job ID cols.
+                # Use "*" (or "" for family rows) until slot is populated.
                 job_id = summary[id].get('submit_method_id')
                 batch_sys_name = summary[id].get('batch_sys_name')
                 host = summary[id].get('host')
@@ -504,13 +486,12 @@ class TreeUpdater(threading.Thread):
                 row_id_iters = {}
                 self.ttreestore.foreach(
                     self._cache_row_id_iters, row_id_iters)
-            for delete_row_id, prev_location in delete_items:
+            for delete_row_id, _ in delete_items:
                 real_location = row_id_iters.get(delete_row_id)
                 if real_location is None:
                     continue
-                delete_iter, delete_path = real_location
+                delete_iter = real_location[0]
                 if self.ttreestore.iter_is_valid(delete_iter):
-                    path = self.ttreestore.get_path(delete_iter)
                     self.ttreestore.remove(delete_iter)
         else:  # not should_rebuild_tree
             # Update the tree in place - no row has been added or deleted.
@@ -622,7 +603,6 @@ class TreeUpdater(threading.Thread):
     def _add_expanded_row(self, view, rpath, expand_me):
         """Add user-expanded rows to a list of rows to be expanded."""
         model = view.get_model()
-        row_iter = model.get_iter(rpath)
         row_id = self._get_row_id(model, rpath)
         if not self.autoexpand or row_id not in self._last_autoexpand_me:
             expand_me.append(row_id)
@@ -686,7 +666,7 @@ class TreeUpdater(threading.Thread):
         sub_st = self.ttree_paths.get(path, {}).get('states', [])
         point_string = self.ttreestore.get_value(row_iter, 0)
         name = self.ttreestore.get_value(row_iter, 1)
-        if any([s in TASK_STATUSES_AUTO_EXPAND for s in sub_st]):
+        if any(s in TASK_STATUSES_AUTO_EXPAND for s in sub_st):
             # return True  # TODO: Option for different expansion rules?
             if point_string == name:
                 # Expand cycle points if any child states comply.
@@ -695,8 +675,7 @@ class TreeUpdater(threading.Thread):
             while child_iter is not None:
                 c_path = self.ttreestore.get_path(child_iter)
                 c_sub_st = self.ttree_paths.get(c_path, {}).get('states', [])
-                if any([s in TASK_STATUSES_AUTO_EXPAND for
-                        s in c_sub_st]):
+                if any(s in TASK_STATUSES_AUTO_EXPAND for s in c_sub_st):
                     # Expand if there are sub-families with valid states.
                     # Do not expand if it's just tasks with valid states.
                     return True
@@ -705,8 +684,6 @@ class TreeUpdater(threading.Thread):
         return False
 
     def run(self):
-        glbl = None
-        states = {}
         while not self.quit:
             if self.update():
                 gobject.idle_add(self.update_gui)
