@@ -206,6 +206,9 @@ class JobFileWriter(object):
             ' '.join(job_conf['namespace_hierarchy']))
         handle.write(
             '\n    export CYLC_TASK_TRY_NUMBER=%s' % job_conf['try_num'])
+        if job_conf['param_var']:
+            for var, val in job_conf['param_var'].items():
+                handle.write('\n    export %s="%s"' % (var, val))
         if job_conf['work_d']:
             # Note: not an environment variable, but used by job.sh
             handle.write(
