@@ -19,5 +19,5 @@
 
 from cylc.network.method import METHOD
 
-if METHOD == "https":
+if METHOD in ["https", "http"]:
     from cylc.network.https.daemon import CommsDaemon
