@@ -20,6 +20,6 @@
 from cylc.network.method import METHOD
 
 
-if METHOD == "https":
+if METHOD in ["https", "http"]:
     from cylc.network.https.suite_info_client import (
         SuiteInfoClient, SuiteInfoClientAnon)
