@@ -20,7 +20,7 @@
 from optparse import OptionParser, OptionConflictError
 import os
 import cylc.flags
-from cylc.owner import USER
+from cylc.suite_host import get_user
 
 
 class CylcOptionParser(OptionParser):
@@ -116,7 +116,7 @@ Arguments:"""
                 "Other user account name. This results in "
                 "command reinvocation on the remote account."
             ),
-            metavar="USER", default=USER,
+            metavar="USER", default=get_user(),
             action="store", dest="owner")
         self.add_std_option(
             "--host",
