@@ -53,11 +53,10 @@ from cylc.network.suite_info_server import SuiteInfoServer
 from cylc.network.suite_log_server import SuiteLogServer
 from cylc.network.suite_state_server import StateSummaryServer
 from cylc.network.task_msg_server import TaskMessageServer
-from cylc.owner import USER
 from cylc.suite_db_mgr import SuiteDatabaseManager
 from cylc.suite_events import (
     SuiteEventContext, SuiteEventError, SuiteEventHandler)
-from cylc.suite_host import get_suite_host
+from cylc.suite_host import get_suite_host, get_user
 from cylc.suite_logging import SuiteLog, OUT, ERR, LOG
 from cylc.suite_srv_files_mgr import (
     SuiteSrvFilesManager, SuiteServiceFileError)
@@ -139,6 +138,8 @@ class Scheduler(object):
         self.config = None
 
         self.is_restart = is_restart
+        if self.is_restart:
+            self.restart_warm_point = None
         self._cli_initial_point_string = None
         self._cli_start_point_string = None
         start_point_str = None
@@ -153,7 +154,7 @@ class Scheduler(object):
 
         self.run_mode = self.options.run_mode
 
-        self.owner = USER
+        self.owner = get_user()
         self.host = get_suite_host()
         self.port = None
 
@@ -216,14 +217,17 @@ class Scheduler(object):
             self.suite_db_mgr.restart_upgrade()
 
         try:
-            if not self.options.no_detach and not cylc.flags.debug:
+            detach = not (self.options.no_detach or cylc.flags.debug)
+
+            if detach:
                 daemonize(self)
 
+            # Setup the suite log.
             slog = SuiteLog.get_inst(self.suite)
             if cylc.flags.debug:
-                slog.pimp(DEBUG)
+                slog.pimp(detach, DEBUG)
             else:
-                slog.pimp()
+                slog.pimp(detach)
 
             self.proc_pool = SuiteProcPool()
             self.configure_comms_daemon()
@@ -307,7 +311,6 @@ conditions; see `cylc conditions`.
             if reqmode != self.run_mode:
                 raise SchedulerError(
                     'ERROR: this suite requires the %s run mode' % reqmode)
-
         self.suite_event_handler = SuiteEventHandler(self.proc_pool)
         self.task_job_mgr = TaskJobManager(
             self.suite, self.proc_pool, self.suite_db_mgr,
@@ -316,7 +319,8 @@ conditions; see `cylc conditions`.
         self.task_events_mgr.mail_interval = self._get_cylc_conf(
             "task event mail interval")
         self.task_events_mgr.mail_footer = self._get_events_conf("mail footer")
-        self.task_events_mgr.suite_url = self.config.cfg['URL']
+        self.task_events_mgr.suite_url = self.config.cfg['meta']['URL']
+        self.task_events_mgr.suite_cfg = self.config.cfg['meta']
         if self.options.genref or self.options.reftest:
             self.configure_reftest()
 
@@ -349,7 +353,8 @@ conditions; see `cylc conditions`.
             self.initial_point,
             self.final_point,
             self.pool.is_held,
-            self.config.cfg['cylc']['cycle point format'])
+            self.config.cfg['cylc']['cycle point format'],
+            self._cli_start_point_string)
         self.suite_db_mgr.put_suite_template_vars(self.template_vars)
         self.configure_suite_environment()
 
@@ -403,6 +408,8 @@ conditions; see `cylc conditions`.
         """Load tasks for restart."""
         self.suite_db_mgr.pri_dao.select_suite_params(
             self._load_suite_params, self.options.checkpoint)
+        if self.restart_warm_point:
+            self.start_point = self.restart_warm_point
         self.suite_db_mgr.pri_dao.select_broadcast_states(
             BroadcastServer.get_inst().load_db_broadcast_states,
             self.options.checkpoint)
@@ -593,8 +600,8 @@ conditions; see `cylc conditions`.
 
     def info_get_suite_info(self):
         """Return a dict containing the suite title and description."""
-        return {'title': self.config.cfg['title'],
-                'description': self.config.cfg['description']}
+        return {'title': self.config.cfg['meta']['title'],
+                'description': self.config.cfg['meta']['description']}
 
     def info_get_task_info(self, names):
         """Return info of a task."""
@@ -842,7 +849,9 @@ conditions; see `cylc conditions`.
                 ['task messaging', 'retry interval']))),
             mgr.KEY_TASK_MSG_TIMEOUT: str(float(GLOBAL_CFG.get(
                 ['task messaging', 'connection timeout']))),
-            mgr.KEY_VERSION: CYLC_VERSION}
+            mgr.KEY_VERSION: CYLC_VERSION,
+            mgr.KEY_COMMS_PROTOCOL: GLOBAL_CFG.get(
+                ['communication', 'method'])}
         try:
             mgr.dump_contact_file(self.suite, contact_data)
         except IOError as exc:
@@ -900,6 +909,13 @@ conditions; see `cylc conditions`.
             self._cli_initial_point_string = value
             self.do_process_tasks = True
 
+    def _load_warm_cycle_point(self, _, row):
+        """Load previous warm start point on restart"""
+        key, value = row
+        if key == "warm_point":
+            self._cli_start_point_string = value
+            self.restart_warm_point = value
+
     def _load_template_vars(self, _, row):
         """Load suite start up template variables."""
         key, value = row
@@ -918,6 +934,7 @@ conditions; see `cylc conditions`.
             pri_dao = self.suite_db_mgr.get_pri_dao()
             pri_dao.select_suite_params(self._load_initial_cycle_point)
             pri_dao.select_suite_template_vars(self._load_template_vars)
+            pri_dao.select_suite_params(self._load_warm_cycle_point)
             # Take checkpoint and commit immediately so that checkpoint can be
             # copied to the public database.
             pri_dao.take_checkpoints("restart")
@@ -1094,30 +1111,183 @@ conditions; see `cylc conditions`.
             if event == self.EVENT_SHUTDOWN and self.options.reftest:
                 OUT.info('SUITE REFERENCE TEST PASSED')
 
-    def run(self):
-        """Main loop."""
+    def initialise_scheduler(self):
+        """Prelude to the main scheduler loop.
+
+        Determines whether suite is held or should be held.
+        Determines whether suite can be auto shutdown.
+        Begins profile logs if needed.
+        """
         if self.pool_hold_point is not None:
             self.hold_suite(self.pool_hold_point)
-
         if self.options.start_held:
             LOG.info("Held on start-up (no tasks will be submitted)")
             self.hold_suite()
-
         self.run_event_handlers(self.EVENT_STARTUP, 'suite starting')
-
         self.profiler.log_memory("scheduler.py: begin run while loop")
-
-        time_next_fs_check = None
+        self.time_next_fs_check = None
         cylc.flags.iflag = True
-
         if self.options.profile_mode:
-            previous_profile_point = 0
-            count = 0
-
-        can_auto_stop = (
+            self.previous_profile_point = 0
+            self.count = 0
+        self.can_auto_stop = (
             not self.config.cfg['cylc']['disable automatic shutdown'] and
             not self.options.no_auto_shutdown)
 
+    def process_task_pool(self):
+        """Process ALL TASKS whenever something has changed that might
+        require renegotiation of dependencies, etc"""
+        if cylc.flags.debug:
+            LOG.debug("BEGIN TASK PROCESSING")
+            time0 = time()
+        self.pool.match_dependencies()
+        if self.stop_mode is None:
+            itasks = self.pool.get_ready_tasks()
+            if itasks:
+                cylc.flags.iflag = True
+            if self.config.cfg['cylc']['log resolved dependencies']:
+                for itask in itasks:
+                    if itask.local_job_file_path:
+                        continue
+                    deps = itask.state.get_resolved_dependencies()
+                    LOG.info('triggered off %s' % deps, itask=itask)
+
+            self.task_job_mgr.submit_task_jobs(
+                self.suite, itasks, self.run_mode == 'simulation')
+        for meth in [
+                self.pool.spawn_all_tasks,
+                self.pool.remove_spent_tasks,
+                self.pool.remove_suiciding_tasks]:
+            if meth():
+                cylc.flags.iflag = True
+
+        BroadcastServer.get_inst().expire(self.pool.get_min_point())
+        if cylc.flags.debug:
+            LOG.debug("END TASK PROCESSING (took %s seconds)" %
+                      (time() - time0))
+
+    def process_queued_task_operations(self):
+        try:
+            self.suite_db_mgr.process_queued_ops()
+        except OSError as err:
+            if cylc.flags.debug:
+                ERR.debug(traceback.format_exc())
+            raise SchedulerError(str(err))
+
+    def database_health_check(self):
+        """If public database is stuck, blast it away by copying the content
+        of the private database into it."""
+        try:
+            self.suite_db_mgr.recover_pub_from_pri()
+        except (IOError, OSError) as exc:
+            # Something has to be very wrong here, so stop the suite
+            raise SchedulerError(str(exc))
+
+    def timeout_check(self):
+        self.check_suite_timer()
+        if self._get_events_conf(self.EVENT_INACTIVITY_TIMEOUT):
+            self.check_suite_inactive()
+        # check submission and execution timeout and polling timers
+        if self.run_mode != 'simulation':
+            self.task_job_mgr.check_task_jobs(self.suite, self.pool)
+
+    def suite_shutdown(self):
+        """Determines if the suite can be shutdown yet."""
+        if (self.config.cfg['cylc']['abort if any task fails'] and
+                self.pool.any_task_failed()):
+            # Task failure + abort if any task fails
+            self._set_stop(TaskPool.STOP_AUTO_ON_TASK_FAILURE)
+        elif self.options.reftest and self.ref_test_allowed_failures:
+            # In reference test mode and unexpected failures occured
+            bad_tasks = []
+            for itask in self.pool.get_failed_tasks():
+                if itask.identity not in self.ref_test_allowed_failures:
+                    bad_tasks.append(itask)
+            if bad_tasks:
+                sys.stderr.write(
+                    'Failed task(s) not in allowed failures list:\n')
+                for itask in bad_tasks:
+                    sys.stderr.write("\t%s\n" % itask.identity)
+                self._set_stop(TaskPool.STOP_AUTO_ON_TASK_FAILURE)
+
+        # Can suite shut down automatically?
+        if self.stop_mode is None and (
+                self.stop_clock_done() or self.stop_task_done() or
+                self.can_auto_stop and self.pool.check_auto_shutdown()):
+            self._set_stop(TaskPool.STOP_AUTO)
+
+        # Is the suite ready to shut down now?
+        if self.pool.can_stop(self.stop_mode):
+            self.update_state_summary()
+            self.proc_pool.close()
+            if self.stop_mode != TaskPool.STOP_REQUEST_NOW_NOW:
+                # Wait for process pool to complete,
+                # unless --now --now is requested
+                stop_process_pool_empty_msg = (
+                    "Waiting for the command process pool to empty" +
+                    " for shutdown")
+                while not self.proc_pool.is_dead():
+                    sleep(self.INTERVAL_STOP_PROCESS_POOL_EMPTY)
+                    if stop_process_pool_empty_msg:
+                        LOG.info(stop_process_pool_empty_msg)
+                        OUT.info(stop_process_pool_empty_msg)
+                        stop_process_pool_empty_msg = None
+                    self.proc_pool.handle_results_async()
+                    self.process_command_queue()
+            if self.options.profile_mode:
+                self.profiler.log_memory(
+                    "scheduler.py: end main loop (total loops %d): %s" %
+                    (self.count, get_current_time_string()))
+            if self.stop_mode == TaskPool.STOP_AUTO_ON_TASK_FAILURE:
+                raise SchedulerError(self.stop_mode)
+            else:
+                raise SchedulerStop(self.stop_mode)
+        elif (self.time_next_kill is not None and
+                time() > self.time_next_kill):
+            self.command_poll_tasks()
+            self.command_kill_tasks()
+            self.time_next_kill = time() + self.INTERVAL_STOP_KILL
+
+    def suite_health_check(self, has_changes):
+        if self.stop_mode is None and not has_changes:
+            self.check_suite_stalled()
+        now = time()
+
+        if self.time_next_fs_check is None or now > self.time_next_fs_check:
+            if not os.path.exists(self.suite_run_dir):
+                raise SchedulerError(
+                    "%s: suite run directory not found" % self.suite_run_dir)
+            try:
+                contact_data = self.suite_srv_files_mgr.load_contact_file(
+                    self.suite)
+                assert contact_data == self.contact_data
+            except (AssertionError, IOError, ValueError,
+                    SuiteServiceFileError):
+                ERR.critical(traceback.format_exc())
+                exc = SchedulerError(
+                    ("%s: suite contact file corrupted/modified and" +
+                     " may be left") %
+                    self.suite_srv_files_mgr.get_contact_file(self.suite))
+                raise exc
+            self.time_next_fs_check = (
+                now + self._get_cylc_conf('health check interval'))
+
+    def update_profiler_logs(self, tinit):
+        now = time()
+        self._update_profile_info("scheduler loop dt (s)", now - tinit,
+                                  amount_format="%.3f")
+        self._update_cpu_usage()
+        if now - self.previous_profile_point >= 60:
+            # Only get this every minute.
+            self.previous_profile_point = now
+            self.profiler.log_memory("scheduler.py: loop #%d: %s" % (
+                self.count, get_current_time_string()))
+        self.count += 1
+
+    def run(self):
+        """Main loop."""
+
+        self.initialise_scheduler()
         while True:  # MAIN LOOP
             tinit = time()
 
@@ -1138,156 +1308,37 @@ conditions; see `cylc conditions`.
             # PROCESS ALL TASKS whenever something has changed that might
             # require renegotiation of dependencies, etc.
             if self.process_tasks():
-                if cylc.flags.debug:
-                    LOG.debug("BEGIN TASK PROCESSING")
-                    time0 = time()
-
-                self.pool.match_dependencies()
-                if self.stop_mode is None:
-                    itasks = self.pool.get_ready_tasks()
-                    if itasks:
-                        cylc.flags.iflag = True
-                    if self.config.cfg['cylc']['log resolved dependencies']:
-                        for itask in itasks:
-                            if itask.local_job_file_path:
-                                continue
-                            deps = itask.state.get_resolved_dependencies()
-                            LOG.info('triggered off %s' % deps, itask=itask)
-                    self.task_job_mgr.submit_task_jobs(
-                        self.suite, itasks, self.run_mode == 'simulation')
-                for meth in [
-                        self.pool.spawn_all_tasks,
-                        self.pool.remove_spent_tasks,
-                        self.pool.remove_suiciding_tasks]:
-                    if meth():
-                        cylc.flags.iflag = True
-
-                BroadcastServer.get_inst().expire(self.pool.get_min_point())
-
-                if cylc.flags.debug:
-                    LOG.debug(
-                        "END TASK PROCESSING (took %s seconds)" %
-                        (time() - time0))
+                self.process_task_pool()
 
             self.process_queued_task_messages()
             self.process_command_queue()
             self.task_events_mgr.process_events(self)
+
+            # Update database
             self.suite_db_mgr.put_task_event_timers(self.task_events_mgr)
             has_changes = cylc.flags.iflag
             if cylc.flags.iflag:
                 self.suite_db_mgr.put_task_pool(self.pool)
                 self.update_state_summary()  # Will reset cylc.flags.iflag
-            try:
-                self.suite_db_mgr.process_queued_ops()
-            except OSError as err:
-                if cylc.flags.debug:
-                    ERR.debug(traceback.format_exc())
-                raise SchedulerError(str(err))
+
+            # Process queued operations for each task proxy
+            self.process_queued_task_operations()
+
             # If public database is stuck, blast it away by copying the content
             # of the private database into it.
-            try:
-                self.suite_db_mgr.recover_pub_from_pri()
-            except (IOError, OSError) as exc:
-                # Something has to be very wrong here, so stop the suite
-                raise SchedulerError(str(exc))
-            self.check_suite_timer()
-            if self._get_events_conf(self.EVENT_INACTIVITY_TIMEOUT):
-                self.check_suite_inactive()
-            # check submission and execution timeout and polling timers
-            if self.run_mode != 'simulation':
-                self.task_job_mgr.check_task_jobs(self.suite, self.pool)
+            self.database_health_check()
+
+            # Shutdown suite if timeouts have occurred
+            self.timeout_check()
 
             # Does the suite need to shutdown on task failure?
-            if (self.config.cfg['cylc']['abort if any task fails'] and
-                    self.pool.any_task_failed()):
-                # Task failure + abort if any task fails
-                self._set_stop(TaskPool.STOP_AUTO_ON_TASK_FAILURE)
-            elif self.options.reftest and self.ref_test_allowed_failures:
-                # In reference test mode and unexpected failures occured
-                bad_tasks = []
-                for itask in self.pool.get_failed_tasks():
-                    if itask.identity not in self.ref_test_allowed_failures:
-                        bad_tasks.append(itask)
-                if bad_tasks:
-                    sys.stderr.write(
-                        'Failed task(s) not in allowed failures list:\n')
-                    for itask in bad_tasks:
-                        sys.stderr.write("\t%s\n" % itask.identity)
-                    self._set_stop(TaskPool.STOP_AUTO_ON_TASK_FAILURE)
-
-            # Can suite shut down automatically?
-            if self.stop_mode is None and (
-                    self.stop_clock_done() or self.stop_task_done() or
-                    can_auto_stop and self.pool.check_auto_shutdown()):
-                self._set_stop(TaskPool.STOP_AUTO)
-
-            # Is the suite ready to shut down now?
-            if self.pool.can_stop(self.stop_mode):
-                self.update_state_summary()
-                self.proc_pool.close()
-                if self.stop_mode != TaskPool.STOP_REQUEST_NOW_NOW:
-                    # Wait for process pool to complete,
-                    # unless --now --now is requested
-                    stop_process_pool_empty_msg = (
-                        "Waiting for the command process pool to empty" +
-                        " for shutdown")
-                    while not self.proc_pool.is_dead():
-                        sleep(self.INTERVAL_STOP_PROCESS_POOL_EMPTY)
-                        if stop_process_pool_empty_msg:
-                            LOG.info(stop_process_pool_empty_msg)
-                            OUT.info(stop_process_pool_empty_msg)
-                            stop_process_pool_empty_msg = None
-                        self.proc_pool.handle_results_async()
-                        self.process_command_queue()
-                if self.options.profile_mode:
-                    self.profiler.log_memory(
-                        "scheduler.py: end main loop (total loops %d): %s" %
-                        (count, get_current_time_string()))
-                if self.stop_mode == TaskPool.STOP_AUTO_ON_TASK_FAILURE:
-                    raise SchedulerError(self.stop_mode)
-                else:
-                    raise SchedulerStop(self.stop_mode)
-            elif (self.time_next_kill is not None and
-                    time() > self.time_next_kill):
-                self.command_poll_tasks()
-                self.command_kill_tasks()
-                self.time_next_kill = time() + self.INTERVAL_STOP_KILL
+            self.suite_shutdown()
 
             # Suite health checks
-            if self.stop_mode is None and not has_changes:
-                self.check_suite_stalled()
-            now = time()
-            if time_next_fs_check is None or now > time_next_fs_check:
-                if not os.path.exists(self.suite_run_dir):
-                    raise SchedulerError(
-                        "%s: suite run directory not found" %
-                        self.suite_run_dir)
-                try:
-                    contact_data = self.suite_srv_files_mgr.load_contact_file(
-                        self.suite)
-                    assert contact_data == self.contact_data
-                except (AssertionError, IOError, ValueError,
-                        SuiteServiceFileError):
-                    ERR.critical(traceback.format_exc())
-                    exc = SchedulerError(
-                        ("%s: suite contact file corrupted/modified and" +
-                         " may be left") %
-                        self.suite_srv_files_mgr.get_contact_file(self.suite))
-                    raise exc
-                time_next_fs_check = (
-                    now + self._get_cylc_conf('health check interval'))
+            self.suite_health_check(has_changes)
 
             if self.options.profile_mode:
-                now = time()
-                self._update_profile_info("scheduler loop dt (s)", now - tinit,
-                                          amount_format="%.3f")
-                self._update_cpu_usage()
-                if now - previous_profile_point >= 60:
-                    # Only get this every minute.
-                    previous_profile_point = now
-                    self.profiler.log_memory("scheduler.py: loop #%d: %s" % (
-                        count, get_current_time_string()))
-                count += 1
+                self.update_profiler_logs(tinit)
 
             sleep(self.INTERVAL_MAIN_LOOP)
             # END MAIN LOOP
@@ -1406,21 +1457,12 @@ conditions; see `cylc conditions`.
                 handle = open(
                     os.path.join(self.config.fdir, 'reference.log'), 'wb')
                 for line in open(self.suite_log.get_log_path(SuiteLog.LOG)):
-                    if any([text in line for text in self.REF_LOG_TEXTS]):
+                    if any(text in line for text in self.REF_LOG_TEXTS):
                         handle.write(line)
                 handle.close()
             except IOError as exc:
                 ERR.error(str(exc))
 
-        if self.pool is not None:
-            self.pool.warn_stop_orphans()
-            try:
-                self.suite_db_mgr.put_task_event_timers(self.task_events_mgr)
-                self.suite_db_mgr.put_task_pool(self.pool)
-                self.suite_db_mgr.process_queued_ops()
-            except Exception as exc:
-                ERR.error(str(exc))
-
         if self.proc_pool:
             if not self.proc_pool.is_dead():
                 # e.g. KeyboardInterrupt
@@ -1428,6 +1470,14 @@ conditions; see `cylc conditions`.
             self.proc_pool.join()
             self.proc_pool.handle_results_async()
 
+        if self.pool is not None:
+            self.pool.warn_stop_orphans()
+            try:
+                self.suite_db_mgr.put_task_event_timers(self.task_events_mgr)
+                self.suite_db_mgr.put_task_pool(self.pool)
+            except Exception as exc:
+                ERR.error(str(exc))
+
         if self.comms_daemon:
             ifaces = [self.command_queue,
                       SuiteIdServer.get_inst(), StateSummaryServer.get_inst(),
@@ -1457,7 +1507,11 @@ conditions; see `cylc conditions`.
                 self.task_job_mgr.unlink_hosts_contacts(self.suite)
 
         # disconnect from suite-db, stop db queue
-        self.suite_db_mgr.on_suite_shutdown()
+        try:
+            self.suite_db_mgr.process_queued_ops()
+            self.suite_db_mgr.on_suite_shutdown()
+        except StandardError as exc:
+            ERR.error(str(exc))
 
         if getattr(self, "config", None) is not None:
             # run shutdown handlers
