@@ -46,7 +46,9 @@ class SuiteDatabaseManager(object):
     TABLE_SUITE_TEMPLATE_VARS = CylcSuiteDAO.TABLE_SUITE_TEMPLATE_VARS
     TABLE_TASK_ACTION_TIMERS = CylcSuiteDAO.TABLE_TASK_ACTION_TIMERS
     TABLE_TASK_POOL = CylcSuiteDAO.TABLE_TASK_POOL
+    TABLE_TASK_OUTPUTS = CylcSuiteDAO.TABLE_TASK_OUTPUTS
     TABLE_TASK_STATES = CylcSuiteDAO.TABLE_TASK_STATES
+    TABLE_TASK_TIMEOUT_TIMERS = CylcSuiteDAO.TABLE_TASK_TIMEOUT_TIMERS
 
     def __init__(self, pri_d=None, pub_d=None):
         self.pri_path = None
@@ -61,14 +63,18 @@ class SuiteDatabaseManager(object):
         self.db_deletes_map = {
             self.TABLE_SUITE_PARAMS: [],
             self.TABLE_TASK_POOL: [],
-            self.TABLE_TASK_ACTION_TIMERS: []}
+            self.TABLE_TASK_ACTION_TIMERS: [],
+            self.TABLE_TASK_OUTPUTS: [],
+            self.TABLE_TASK_TIMEOUT_TIMERS: []}
         self.db_inserts_map = {
             self.TABLE_INHERITANCE: [],
             self.TABLE_SUITE_PARAMS: [],
             self.TABLE_SUITE_TEMPLATE_VARS: [],
             self.TABLE_CHECKPOINT_ID: [],
             self.TABLE_TASK_POOL: [],
-            self.TABLE_TASK_ACTION_TIMERS: []}
+            self.TABLE_TASK_ACTION_TIMERS: [],
+            self.TABLE_TASK_OUTPUTS: [],
+            self.TABLE_TASK_TIMEOUT_TIMERS: []}
         self.db_updates_map = {}
 
     def checkpoint(self, name):
@@ -145,6 +151,8 @@ class SuiteDatabaseManager(object):
 
     def process_queued_ops(self):
         """Handle queued db operations for each task proxy."""
+        if self.pri_dao is None:
+            return
         # Record suite parameters and tasks in pool
         # Record any broadcast settings to be dumped out
         for obj in self, BroadcastServer.get_inst():
@@ -194,7 +202,7 @@ class SuiteDatabaseManager(object):
 
     def put_suite_params(
             self, run_mode, initial_point, final_point, is_held,
-            cycle_point_format=None):
+            cycle_point_format=None, warm_point=None):
         """Put run mode, initial/final cycle point in runtime database.
 
         This method queues the relevant insert statements.
@@ -211,6 +219,10 @@ class SuiteDatabaseManager(object):
         if is_held:
             self.db_inserts_map[self.TABLE_SUITE_PARAMS].append(
                 {"key": "is_held", "value": 1})
+        if warm_point:
+            self.db_inserts_map[self.TABLE_SUITE_PARAMS].append(
+                {"key": "warm_point", "value": str(warm_point)}
+            )
 
     def put_suite_template_vars(self, template_vars):
         """Put template_vars in runtime database.
@@ -245,6 +257,10 @@ class SuiteDatabaseManager(object):
         relevant insert statements for the current tasks in the pool.
         """
         self.db_deletes_map[self.TABLE_TASK_POOL].append({})
+        # No need to do:
+        # self.db_deletes_map[self.TABLE_TASK_ACTION_TIMERS].append({})
+        # Should already be done by self.put_task_event_timers above.
+        self.db_deletes_map[self.TABLE_TASK_TIMEOUT_TIMERS].append({})
         for itask in pool.get_all_tasks():
             self.db_inserts_map[self.TABLE_TASK_POOL].append({
                 "name": itask.tdef.name,
@@ -252,6 +268,11 @@ class SuiteDatabaseManager(object):
                 "spawned": int(itask.has_spawned),
                 "status": itask.state.status,
                 "hold_swap": itask.state.hold_swap})
+            if itask.state.status in itask.timeout_timers:
+                self.db_inserts_map[self.TABLE_TASK_TIMEOUT_TIMERS].append({
+                    "name": itask.tdef.name,
+                    "cycle": str(itask.point),
+                    "timeout": itask.timeout_timers[itask.state.status]})
             for ctx_key_0 in ["poll_timers", "try_timers"]:
                 for ctx_key_1, timer in getattr(itask, ctx_key_0).items():
                     if timer is None:
@@ -298,6 +319,10 @@ class SuiteDatabaseManager(object):
         """Put INSERT statement for task_states table."""
         self._put_insert_task_x(CylcSuiteDAO.TABLE_TASK_STATES, itask, args)
 
+    def put_insert_task_outputs(self, itask):
+        """Reset custom outputs for a task."""
+        self._put_insert_task_x(CylcSuiteDAO.TABLE_TASK_OUTPUTS, itask, {})
+
     def _put_insert_task_x(self, table_name, itask, args):
         """Put INSERT statement for a task_* table."""
         args.update({
@@ -313,6 +338,15 @@ class SuiteDatabaseManager(object):
         self._put_update_task_x(
             CylcSuiteDAO.TABLE_TASK_JOBS, itask, set_args)
 
+    def put_update_task_outputs(self, itask):
+        """Put UPDATE statement for task_outputs table."""
+        items = []
+        for item in sorted(itask.state.outputs.get_completed_customs()):
+            items.append("%s=%s" % item)
+        self._put_update_task_x(
+            CylcSuiteDAO.TABLE_TASK_OUTPUTS,
+            itask, {"outputs": "\n".join(items)})
+
     def put_update_task_states(self, itask, set_args):
         """Put UPDATE statement for task_states table."""
         self._put_update_task_x(
@@ -369,7 +403,8 @@ class SuiteDatabaseManager(object):
                 os.unlink(os.path.join(suite_run_d, "cylc-suite-env"))
             except OSError:
                 pass
-        elif os.path.exists(old_pri_db_path_611):
+        elif (os.path.exists(old_pri_db_path_611) and
+                not os.path.exists(self.pri_path)):
             # Upgrade 6.11.X runtime database
             os.rename(old_pri_db_path_611, self.pri_path)
             pri_dao = self.get_pri_dao()
