@@ -26,9 +26,8 @@ import sys
 
 import cylc.flags
 from cylc.mkdir_p import mkdir_p
-from cylc.owner import USER, is_remote_user
 from cylc.suite_host import (
-    get_local_ip_address, get_suite_host, is_remote_host)
+    get_local_ip_address, get_suite_host, get_user, is_remote, is_remote_host)
 
 
 class SuiteServiceFileError(Exception):
@@ -61,6 +60,7 @@ class SuiteSrvFilesManager(object):
     KEY_VERSION = "CYLC_VERSION"
     PASSPHRASE_CHARSET = ascii_letters + digits
     PASSPHRASE_LEN = 20
+    KEY_COMMS_PROTOCOL = "CYLC_COMMS_PROTOCOL"  # default (or none?)
 
     def __init__(self):
         self.local_passphrases = set()
@@ -76,7 +76,7 @@ class SuiteSrvFilesManager(object):
         the remote passphrase in memory as well.
         """
         if owner is None:
-            owner = USER
+            owner = get_user()
         if host is None:
             host = get_suite_host()
         path = self._get_cache_dir(reg, owner, host)
@@ -206,13 +206,12 @@ To see if %(suite)s is running on '%(host)s:%(port)s':
         """
         if item not in [
                 self.FILE_BASE_SSL_CERT, self.FILE_BASE_SSL_PEM,
-                self.FILE_BASE_PASSPHRASE, self.FILE_BASE_CONTACT]:
+                self.FILE_BASE_PASSPHRASE, self.FILE_BASE_CONTACT,
+                self.KEY_COMMS_PROTOCOL]:
             raise ValueError("%s: item not recognised" % item)
         if item == self.FILE_BASE_PASSPHRASE:
             self.can_disk_cache_passphrases[(reg, owner, host)] = False
 
-        suite_host = os.getenv('CYLC_SUITE_HOST')
-        suite_owner = os.getenv('CYLC_SUITE_OWNER')
         if reg == os.getenv('CYLC_SUITE_NAME'):
             env_keys = []
             if 'CYLC_SUITE_RUN_DIR' in os.environ:
@@ -229,20 +228,18 @@ To see if %(suite)s is running on '%(host)s:%(port)s':
                     value = self._locate_item(item, path)
                 if value:
                     return value
-
         # 2/ From memory cache
         if item in self.cache:
             my_owner = owner
             my_host = host
             if my_owner is None:
-                my_owner = USER
+                my_owner = get_user()
             if my_host is None:
                 my_host = get_suite_host()
             try:
                 return self.cache[item][(reg, my_owner, my_host)]
             except KeyError:
                 pass
-
         # 3/ Local suite service directory
         if self._is_local_auth_ok(reg, owner, host):
             path = self.get_suite_srv_dir(reg)
@@ -252,7 +249,6 @@ To see if %(suite)s is running on '%(host)s:%(port)s':
                 value = self._locate_item(item, path)
             if value:
                 return value
-
         # 4/ Disk cache for remote suites
         if owner is not None and host is not None:
             paths = [self._get_cache_dir(reg, owner, host)]
@@ -303,7 +299,7 @@ To see if %(suite)s is running on '%(host)s:%(port)s':
     def get_suite_srv_dir(self, reg, suite_owner=None):
         """Return service directory of a suite."""
         if not suite_owner:
-            suite_owner = USER
+            suite_owner = get_user()
         run_d = os.getenv("CYLC_SUITE_RUN_DIR")
         if (not run_d or os.getenv("CYLC_SUITE_NAME") != reg or
                 os.getenv("CYLC_SUITE_OWNER") != suite_owner):
@@ -471,7 +467,7 @@ To see if %(suite)s is running on '%(host)s:%(port)s':
         ext = crypto.X509Extension(
             "subjectAltName",
             False,
-            "DNS:*, DNS:%(dns)s, IP:%(ip)s, DNS:%(ip)s" % {
+            "DNS:%(dns)s, IP:%(ip)s, DNS:%(ip)s" % {
                 "dns": host, "ip": get_local_ip_address(host)})
         file_name = self._locate_item(self.FILE_BASE_SSL_CERT, path)
         if file_name:
@@ -506,7 +502,7 @@ To see if %(suite)s is running on '%(host)s:%(port)s':
 
         1. File permission should already be user-read-write-only on
            creation by mkstemp.
-        2. The combination of os.fsync and os.rename should guarentee
+        2. The combination of os.fsync and os.rename should guarantee
            that we don't end up with an incomplete file.
         """
         mkdir_p(path)
@@ -535,7 +531,10 @@ To see if %(suite)s is running on '%(host)s:%(port)s':
         """
         title = "No title provided"
         for line in open(self.get_suite_rc(reg), 'rb'):
-            if line.lstrip().startswith("["):
+            if line.lstrip().startswith("[meta]"):
+                # continue : title comes inside [meta] section
+                continue
+            elif line.lstrip().startswith("["):
                 # abort: title comes before first [section]
                 break
             match = re.match('^\s*title\s*=\s*(.*)\s*$', line)
@@ -550,7 +549,7 @@ To see if %(suite)s is running on '%(host)s:%(port)s':
         Cache results in self.can_use_load_auths.
         """
         if (reg, owner, host) not in self.can_use_load_auths:
-            if is_remote_user(owner) or is_remote_host(host):
+            if is_remote(host, owner):
                 fname = os.path.join(
                     self.get_suite_srv_dir(reg), self.FILE_BASE_CONTACT)
                 data = {}
@@ -559,13 +558,13 @@ To see if %(suite)s is running on '%(host)s:%(port)s':
                         key, value = (
                             [item.strip() for item in line.split("=", 1)])
                         data[key] = value
-                except IOError, ValueError:
+                except (IOError, ValueError):
                     # No contact file
                     self.can_use_load_auths[(reg, owner, host)] = False
                 else:
                     # Contact file exists, check values match
                     if owner is None:
-                        owner = USER
+                        owner = get_user()
                     if host is None:
                         host = get_suite_host()
                     host_value = data.get(self.KEY_HOST, "")
@@ -591,12 +590,28 @@ To see if %(suite)s is running on '%(host)s:%(port)s':
 
     def _load_remote_item(self, item, reg, owner, host):
         """Load content of service item from remote [owner@]host via SSH."""
-        if not is_remote_host(host) and not is_remote_user(owner):
+        if not is_remote(host, owner):
             return
+        if host is None:
+            host = 'localhost'
+        if owner is None:
+            owner = get_user()
+        from cylc.cfgspec.globalcfg import GLOBAL_CFG
+        if item == 'contact' and not is_remote_host(host):
+            # Attempt to read suite contact file via the local filesystem.
+            path = r'%(run_d)s/%(srv_base)s' % {
+                'run_d': GLOBAL_CFG.get_derived_host_item(
+                    reg, 'suite run directory', host, owner,
+                    replace_home=False),
+                'srv_base': self.DIR_BASE_SRV,
+            }
+            content = self._load_local_item(item, path)
+            if content is not None:
+                return content
+            # Else drop through and attempt via ssh to the suite account.
         # Prefix STDOUT to ensure returned content is relevant
         prefix = r'[CYLC-AUTH] %(suite)s' % {'suite': reg}
         # Attempt to cat passphrase file under suite service directory
-        from cylc.cfgspec.globalcfg import GLOBAL_CFG
         script = (
             r"""echo '%(prefix)s'; """
             r'''cat "%(run_d)s/%(srv_base)s/%(item)s"'''
