@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+from cylc.suite_srv_files_mgr import SuiteServiceFileError
 
 # THIS FILE IS PART OF THE CYLC SUITE ENGINE.
 # Copyright (C) 2008-2017 NIWA
@@ -47,8 +48,7 @@ from cylc.job_file import JobFileWriter
 from cylc.mkdir_p import mkdir_p
 from cylc.mp_pool import SuiteProcPool, SuiteProcContext
 from cylc.network.suite_broadcast_server import BroadcastServer
-from cylc.owner import is_remote_user, USER
-from cylc.suite_host import is_remote_host
+from cylc.suite_host import is_remote, is_remote_host, is_remote_user
 from cylc.suite_logging import ERR, LOG
 from cylc.task_events_mgr import TaskEventsManager
 from cylc.task_message import TaskMessage
@@ -135,8 +135,9 @@ class TaskJobManager(object):
         """
         if host is None:
             host = 'localhost'
-        if ((host, owner) in [('localhost', None), ('localhost', USER)] or
-                (host, owner) in self.init_host_map or self.single_task_mode):
+        if (self.single_task_mode or
+                (host, owner) in self.init_host_map or
+                not is_remote(host, owner)):
             return
         user_at_host = host
         if owner:
@@ -185,14 +186,20 @@ class TaskJobManager(object):
             'task communication method', host, owner) != "poll"
         if should_unlink:
             scp_tmpl = GLOBAL_CFG.get_host_item('scp command', host, owner)
+            # Handle not having SSL certs installed.
+            try:
+                ssl_cert = self.suite_srv_files_mgr.get_auth_item(
+                    self.suite_srv_files_mgr.FILE_BASE_SSL_CERT, reg)
+            except (SuiteServiceFileError, ValueError):
+                ssl_cert = None
             cmds.append(shlex.split(scp_tmpl) + [
                 '-p',
                 self.suite_srv_files_mgr.get_contact_file(reg),
                 self.suite_srv_files_mgr.get_auth_item(
                     self.suite_srv_files_mgr.FILE_BASE_PASSPHRASE, reg),
-                self.suite_srv_files_mgr.get_auth_item(
-                    self.suite_srv_files_mgr.FILE_BASE_SSL_CERT, reg),
                 user_at_host + ':' + r_suite_srv_dir + '/'])
+            if ssl_cert is not None:
+                cmds[-1].insert(-1, ssl_cert)
         # Command to copy python library to remote host.
         suite_run_py = os.path.join(
             GLOBAL_CFG.get_derived_host_item(reg, 'suite run directory'),
@@ -382,16 +389,20 @@ class TaskJobManager(object):
             if timeout is None or now <= timeout:
                 return False
             itask.timeout_timers[itask.state.status] = None
-            if itask.state.status == TASK_STATUS_RUNNING:
+            if (itask.state.status == TASK_STATUS_RUNNING and
+                    itask.summary['started_time'] is not None):
                 msg = 'job started %s ago, but has not finished' % (
                     get_seconds_as_interval_string(
                         timeout - itask.summary['started_time']))
                 event = 'execution timeout'
-            else:  # if itask.state.status == TASK_STATUS_SUBMITTED:
+            elif (itask.state.status == TASK_STATUS_SUBMITTED and
+                    itask.summary['submitted_time'] is not None):
                 msg = 'job submitted %s ago, but has not started' % (
                     get_seconds_as_interval_string(
                         timeout - itask.summary['submitted_time']))
                 event = 'submission timeout'
+            else:
+                return False
             LOG.warning(msg, itask=itask)
             self.task_events_mgr.setup_event_handlers(itask, event, msg)
             return True
@@ -492,6 +503,7 @@ class TaskJobManager(object):
                 handle.write(user_at_host + line)
         except IOError as exc:
             LOG.warning("%s: write failed\n%s" % (job_activity_log, exc))
+            LOG.warning(user_at_host + line, itask=itask)
 
     def _kill_task_jobs_callback(self, ctx, suite, itasks):
         """Callback when kill tasks command exits."""
@@ -692,12 +704,7 @@ class TaskJobManager(object):
             cmd = ["cylc", cmd_key]
             if cylc.flags.debug:
                 cmd.append("--debug")
-            try:
-                if is_remote_host(host):
-                    cmd.append("--host=%s" % (host))
-            except IOError:
-                # Bad host, run the command any way, command will fail and
-                # callback will deal with it
+            if is_remote_host(host):
                 cmd.append("--host=%s" % (host))
             if is_remote_user(owner):
                 cmd.append("--user=%s" % (owner))
@@ -901,6 +908,8 @@ class TaskJobManager(object):
                     itask.poll_timers[key] = TaskActionTimer(delays=values)
 
         self.init_host(suite, itask.task_host, itask.task_owner)
+        if itask.state.outputs.has_custom_triggers():
+            self.suite_db_mgr.put_update_task_outputs(itask)
         self.suite_db_mgr.put_update_task_jobs(itask, {
             "user_at_host": user_at_host,
             "batch_sys_name": itask.summary['batch_sys_name'],
@@ -918,7 +927,6 @@ class TaskJobManager(object):
                 suite, "suite job log directory",
                 itask.task_host, itask.task_owner),
             job_d, self.JOB_FILE_BASE)
-
         return {
             'batch_system_name': rtconfig['job']['batch system'],
             'batch_submit_command_template': (
@@ -935,6 +943,7 @@ class TaskJobManager(object):
             'job_d': job_d,
             'namespace_hierarchy': itask.tdef.namespace_hierarchy,
             'owner': itask.task_owner,
+            'param_var': itask.tdef.param_var,
             'post-script': scripts[2],
             'pre-script': scripts[0],
             'remote_suite_d': rtconfig['remote']['suite definition directory'],
