@@ -60,7 +60,7 @@ class TaskOutputs(object):
     def __init__(self, tdef, point):
         self._by_message = {}
         self._by_trigger = {}
-        for trigger, message in tdef.get_outputs(point):
+        for trigger, message in tdef.outputs:
             self.add(message, trigger)
 
     def add(self, message, trigger=None, is_completed=False):
@@ -93,6 +93,21 @@ class TaskOutputs(object):
                 ret.append(value[_MESSAGE])
         return ret
 
+    def get_completed_customs(self):
+        """Return all completed custom outputs.
+
+        Return a list in this form: [(trigger1, message1), ...]
+        """
+        ret = []
+        for value in self.get_all():
+            if value[_IS_COMPLETED] and value[_TRIGGER] not in _SORT_ORDERS:
+                ret.append((value[_TRIGGER], value[_MESSAGE]))
+        return ret
+
+    def has_custom_triggers(self):
+        """Return True if it has any custom triggers."""
+        return any(key not in _SORT_ORDERS for key in self._by_trigger)
+
     def get_not_completed(self):
         """Return all not-completed output messages."""
         ret = []
@@ -111,7 +126,7 @@ class TaskOutputs(object):
     def remove(self, message=None, trigger=None):
         """Remove an output by message, if it exists."""
         try:
-            trigger, message, _ = self._get_item(message, trigger)
+            trigger, message = self._get_item(message, trigger)[:2]
         except KeyError:
             pass
         else:
@@ -129,7 +144,11 @@ class TaskOutputs(object):
             value[_IS_COMPLETED] = False
 
     def set_completed(self, message=None, trigger=None, is_completed=True):
-        """Set the output identified by message/trigger as completed."""
+        """Set the output identified by message/trigger as completed.
+
+        Return True if completion flag is changed, False if completion is
+        unchanged, or None if message/trigger is not found.
+        """
         try:
             item = self._get_item(message, trigger)
             old_is_completed = item[_IS_COMPLETED]
