@@ -33,7 +33,6 @@ tasks against the new stop cycle.
 
 from fnmatch import fnmatchcase
 import pickle
-from random import randrange
 from time import time
 import traceback
 
@@ -104,18 +103,17 @@ class TaskPool(object):
 
     def assign_queues(self):
         """self.myq[taskname] = qfoo"""
-        qconfig = self.config.cfg['scheduling']['queues']
-        self.myq = {}
-        for queue in qconfig:
-            for taskname in qconfig[queue]['members']:
-                self.myq[taskname] = queue
+        self.myq.clear()
+        for queue, qconfig in self.config.cfg['scheduling']['queues'].items():
+            self.myq.update((name, queue) for name in qconfig['members'])
 
     def insert_tasks(self, items, stop_point_str, no_check=False):
         """Insert tasks."""
         n_warnings = 0
-        task_items = []
+        task_items = {}
+        select_args = []
         for item in items:
-            point_str, name_str, _ = self._parse_task_item(item)
+            point_str, name_str = self._parse_task_item(item)[:2]
             if point_str is None:
                 LOG.warning(
                     "%s: task ID for insert must contain cycle point" % (item))
@@ -134,7 +132,8 @@ class TaskPool(object):
                 n_warnings += 1
                 continue
             for taskdef in taskdefs:
-                task_items.append([(taskdef.name, point_str), taskdef])
+                task_items[(taskdef.name, point_str)] = taskdef
+            select_args.append((name_str, point_str))
         if stop_point_str is None:
             stop_point = None
         else:
@@ -146,15 +145,13 @@ class TaskPool(object):
                     stop_point_str, exc))
                 n_warnings += 1
                 return n_warnings
-        task_states_data = (
-            self.suite_db_mgr.pri_dao.select_task_states_by_task_ids(
-                ["submit_num"], [task_item[0] for task_item in task_items]))
-        for key, taskdef in task_items:
+        submit_nums = self.suite_db_mgr.pri_dao.select_submit_nums_for_insert(
+            select_args)
+        for key, taskdef in sorted(task_items.items()):
             # TODO - insertion of start-up tasks? (startup=False assumed here)
 
             # Check that the cycle point is on one of the tasks sequences.
-            point_str = key[1]
-            point = get_point(point_str)
+            point = get_point(key[1])
             if not no_check:  # Check if cycle point is on the tasks sequence.
                 for sequence in taskdef.sequences:
                     if sequence.is_on_sequence(point):
@@ -162,15 +159,14 @@ class TaskPool(object):
                 else:
                     LOG.warning("%s%s, %s" % (
                         self.ERR_PREFIX_TASK_NOT_ON_SEQUENCE, taskdef.name,
-                        point_str))
+                        key[1]))
                     continue
 
-            submit_num = None
-            if key in task_states_data:
-                submit_num = task_states_data[key].get("submit_num")
-            self.add_to_runahead_pool(TaskProxy(
-                taskdef, get_point(point_str),
-                stop_point=stop_point, submit_num=submit_num))
+            submit_num = submit_nums.get(key)
+            itask = self.add_to_runahead_pool(TaskProxy(
+                taskdef, point, stop_point=stop_point, submit_num=submit_num))
+            if itask:
+                LOG.info("inserted", itask=itask)
         return n_warnings
 
     def add_to_runahead_pool(self, itask, is_restart=False):
@@ -232,6 +228,8 @@ class TaskPool(object):
                 "time_created": get_current_time_string(),
                 "time_updated": get_current_time_string(),
                 "status": itask.state.status})
+            if itask.state.outputs.has_custom_triggers():
+                self.suite_db_mgr.put_insert_task_outputs(itask)
         return itask
 
     def release_runahead_tasks(self):
@@ -245,8 +243,8 @@ class TaskPool(object):
 
         # Any finished tasks can be released immediately (this can happen at
         # restart when all tasks are initially loaded into the runahead pool).
-        for itask_id_maps in self.runahead_pool.values():
-            for itask in itask_id_maps.values():
+        for itask_id_maps in self.runahead_pool.copy().values():
+            for itask in itask_id_maps.copy().values():
                 if itask.state.status in [TASK_STATUS_FAILED,
                                           TASK_STATUS_SUCCEEDED,
                                           TASK_STATUS_EXPIRED]:
@@ -324,9 +322,9 @@ class TaskPool(object):
             latest_allowed_point = self.stop_point
 
         released = False
-        for point, itask_id_map in self.runahead_pool.items():
+        for point, itask_id_map in self.runahead_pool.copy().items():
             if point <= latest_allowed_point:
-                for itask in itask_id_map.values():
+                for itask in itask_id_map.copy().values():
                     self.release_runahead_task(itask)
                     released = True
         return released
@@ -355,12 +353,12 @@ class TaskPool(object):
         if row_idx == 0:
             OUT.info("LOADING task proxies")
         (cycle, name, spawned, status, hold_swap, submit_num, _,
-         user_at_host) = row
+         user_at_host, time_submit, time_run, timeout,
+         outputs_str) = row
         try:
             itask = TaskProxy(
                 self.config.get_taskdef(name),
                 get_point(cycle),
-                status=status,
                 hold_swap=hold_swap,
                 has_spawned=bool(spawned),
                 submit_num=submit_num)
@@ -385,13 +383,19 @@ class TaskPool(object):
                 except ValueError:
                     itask.task_owner = None
                     itask.task_host = user_at_host
+                if time_submit:
+                    itask.set_event_time('submitted', time_submit)
+                if time_run:
+                    itask.set_event_time('started', time_run)
+                if timeout is not None:
+                    itask.timeout_timers[status] = timeout
 
             elif status in (TASK_STATUS_SUBMIT_FAILED, TASK_STATUS_FAILED):
                 itask.state.set_prerequisites_all_satisfied()
 
             elif status in (TASK_STATUS_QUEUED, TASK_STATUS_READY):
                 # reset to waiting as these had not been submitted yet.
-                itask.state.reset_state(TASK_STATUS_WAITING)
+                status = TASK_STATUS_WAITING
                 itask.state.set_prerequisites_all_satisfied()
 
             elif status in (TASK_STATUS_SUBMIT_RETRYING, TASK_STATUS_RETRYING):
@@ -399,8 +403,20 @@ class TaskPool(object):
 
             elif status == TASK_STATUS_SUCCEEDED:
                 itask.state.set_prerequisites_all_satisfied()
-                # TODO - just poll for outputs in the job status file.
-                itask.state.outputs.set_all_completed()
+
+            itask.state.reset_state(status)
+
+            # Tasks that are running or finished can have completed custom
+            # outputs
+            if status in [
+                    TASK_STATUS_RUNNING, TASK_STATUS_FAILED,
+                    TASK_STATUS_SUCCEEDED]:
+                try:
+                    for output in outputs_str.splitlines():
+                        itask.state.outputs.set_completed(
+                            message=output.split("=", 1)[1])
+                except AttributeError:
+                    pass
 
             if user_at_host:
                 itask.summary['job_hosts'][int(submit_num)] = user_at_host
@@ -444,9 +460,11 @@ class TaskPool(object):
 
     def release_runahead_task(self, itask):
         """Release itask to the appropriate queue in the active pool."""
-        queue = self.myq[itask.tdef.name]
-        if queue not in self.queues:
-            self.queues[queue] = {}
+        try:
+            queue = self.myq[itask.tdef.name]
+        except KeyError:
+            queue = self.config.Q_DEFAULT
+        self.queues.setdefault(queue, {})
         self.queues[queue][itask.identity] = itask
         self.pool.setdefault(itask.point, {})
         self.pool[itask.point][itask.identity] = itask
@@ -1060,7 +1078,8 @@ class TaskPool(object):
                     itask.state.reset_state(status)
                     if status in [
                             TASK_STATUS_FAILED, TASK_STATUS_SUBMIT_FAILED]:
-                        itask.set_event_time('finished', time())
+                        itask.set_event_time('finished',
+                                             get_current_time_string())
             if outputs:
                 for output in outputs:
                     is_completed = True
@@ -1091,6 +1110,7 @@ class TaskPool(object):
                             LOG.info(
                                 "reset output to incomplete: %s" % output,
                                 itask=itask)
+                self.suite_db_mgr.put_update_task_outputs(itask)
         return len(bad_items)
 
     def remove_tasks(self, items, spawn=False):
@@ -1308,7 +1328,7 @@ class TaskPool(object):
                     if (fnmatchcase(str(itask.point), point_str) and
                             (not status or itask.state.status == status) and
                             (fnmatchcase(itask.tdef.name, name_str) or
-                             any([fnmatchcase(ns, name_str) for ns in nss]))):
+                             any(fnmatchcase(ns, name_str) for ns in nss))):
                         itasks.append(itask)
                         tasks_found = True
                 if not tasks_found:
