@@ -19,12 +19,10 @@
 """Task definition."""
 
 from collections import deque
-import re
 
 from cylc.cycling.loader import (
     get_point_relative, get_interval, is_offset_absolute)
 from cylc.task_id import TaskID
-from cylc.task_trigger import get_message_offset
 
 
 class TaskDefError(Exception):
@@ -48,8 +46,8 @@ class TaskDef(object):
         "used_in_offset_trigger", "max_future_prereq_offset",
         "intercycle_offsets", "sequential", "is_coldstart",
         "suite_polling_cfg", "clocktrigger_offset", "expiration_offset",
-        "namespace_hierarchy", "triggers", "outputs", "external_triggers",
-        "name", "elapsed_times"]
+        "namespace_hierarchy", "dependencies", "outputs", "param_var",
+        "external_triggers", "name", "elapsed_times"]
 
     # Store the elapsed times for a maximum of 10 cycles
     MAX_LEN_ELAPSED_TIMES = 10
@@ -69,26 +67,33 @@ class TaskDef(object):
 
         # some defaults
         self.max_future_prereq_offset = None
-        self.intercycle_offsets = []
+        self.intercycle_offsets = set([])
         self.sequential = False
         self.suite_polling_cfg = {}
 
         self.clocktrigger_offset = None
         self.expiration_offset = None
         self.namespace_hierarchy = []
-        self.triggers = {}
+        self.dependencies = {}
         self.outputs = []
-
+        self.param_var = {}
         self.external_triggers = []
 
         self.name = name
         self.elapsed_times = deque(maxlen=self.MAX_LEN_ELAPSED_TIMES)
 
-    def add_trigger(self, triggers, expression, sequence):
-        """Add triggers to a named sequence."""
-        if sequence not in self.triggers:
-            self.triggers[sequence] = []
-        self.triggers[sequence].append([triggers, expression])
+    def add_dependency(self, dependency, sequence):
+        """Add a dependency to a named sequence.
+
+        Args:
+            dependency (cylc.task_trigger.Dependency): The dependency to add.
+            sequence (cylc.cycling.SequenceBase): The sequence for which this
+                dependency applies.
+
+        """
+        if sequence not in self.dependencies:
+            self.dependencies[sequence] = []
+        self.dependencies[sequence].append(dependency)
 
     def add_sequence(self, sequence, is_implicit=False):
         """Add a sequence."""
@@ -101,7 +106,7 @@ class TaskDef(object):
         """Return title and description of the current task."""
         info = {}
         for item in 'title', 'description':
-            info[item] = self.rtconfig[item]
+            info[item] = self.rtconfig['meta'][item]
         return info
 
     def check_for_explicit_cycling(self):
@@ -167,12 +172,3 @@ class TaskDef(object):
             return max_cutoff_point
         # There aren't any dependent tasks in other cycles for my_point.
         return my_point
-
-    def get_outputs(self, point):
-        """Return task message outputs for initialisation of TaskOutputs."""
-        for (key, msg), base_interval in self.outputs:
-            new_point = point
-            msg_offset = get_message_offset(msg, base_interval)
-            if msg_offset:
-                new_point = point + msg_offset
-            yield (key, re.sub('\[.*\]', str(new_point), msg))
