@@ -74,31 +74,35 @@ class CylcTimeParser(object):
     """
 
     POINT_INVALID_FOR_CYLC_REGEXES = [
-        (r"^\d\d$", ("2 digit centuries not allowed. " +
-                     "Did you mean T-digit-digit e.g. 'T00'?"))
+        (re.compile(r"^\d\d$"),
+         ("2 digit centuries not allowed. Did you mean T-digit-digit e.g. "
+          "'T00'?"))
     ]
 
     RECURRENCE_FORMAT_REGEXES = [
-        (r"^(?P<start>[^PR/][^/]*)$", 3),
-        (r"^R(?P<reps>\d+)/(?P<start>[^PR/][^/]*)/(?P<end>[^PR/][^/]*)$", 1),
-        (r"^(?P<start>[^PR/][^/]*)/(?P<intv>P[^/]*)/?$", 3),
-        (r"^(?P<intv>P[^/]*)$", 3),
-        (r"^(?P<intv>P[^/]*)/(?P<end>[^PR/][^/]*)$", 4),
-        (r"^R(?P<reps>\d+)?/(?P<start>[^PR/][^/]*)/?$", 3),
-        (r"^R(?P<reps>\d+)?/(?P<start>[^PR/][^/]*)/(?P<intv>P[^/]*)$", 3),
-        (r"^R(?P<reps>\d+)?/(?P<start>)/(?P<intv>P[^/]*)$", 3),
-        (r"^R(?P<reps>\d+)?/(?P<intv>P[^/]*)/(?P<end>[^PR/][^/]*)$", 4),
-        (r"^R(?P<reps>\d+)?/(?P<intv>P[^/]*)/?$", 4),
-        (r"^R(?P<reps>\d+)?//(?P<end>[^PR/][^/]*)$", 4),
-        (r"^R(?P<reps>1)/?(?P<start>$)", 3),
-        (r"^R(?P<reps>1)//(?P<end>[^PR/][^/]*)$", 4)
+        (re.compile(r"^(?P<start>[^PR/][^/]*)$"), 3),
+        (re.compile(r"^R(?P<reps>\d+)/(?P<start>[^PR/][^/]*)/(?P<end>[^PR/]"
+                    "[^/]*)$"), 1),
+        (re.compile(r"^(?P<start>[^PR/][^/]*)/(?P<intv>P[^/]*)/?$"), 3),
+        (re.compile(r"^(?P<intv>P[^/]*)$"), 3),
+        (re.compile(r"^(?P<intv>P[^/]*)/(?P<end>[^PR/][^/]*)$"), 4),
+        (re.compile(r"^R(?P<reps>\d+)?/(?P<start>[^PR/][^/]*)/?$"), 3),
+        (re.compile(r"^R(?P<reps>\d+)?/(?P<start>[^PR/][^/]*)/(?P<intv>P[^/]"
+                    "*)$"), 3),
+        (re.compile(r"^R(?P<reps>\d+)?/(?P<start>)/(?P<intv>P[^/]*)$"), 3),
+        (re.compile(r"^R(?P<reps>\d+)?/(?P<intv>P[^/]*)/(?P<end>[^PR/][^/]*)"
+                    "$"), 4),
+        (re.compile(r"^R(?P<reps>\d+)?/(?P<intv>P[^/]*)/?$"), 4),
+        (re.compile(r"^R(?P<reps>\d+)?//(?P<end>[^PR/][^/]*)$"), 4),
+        (re.compile(r"^R(?P<reps>1)/?(?P<start>$)"), 3),
+        (re.compile(r"^R(?P<reps>1)//(?P<end>[^PR/][^/]*)$"), 4)
     ]
 
-    CHAIN_REGEX = '((?:[+-P]|[\dT])[\d\w]*)'
+    CHAIN_REGEX = re.compile('((?:[+-P]|[\dT])[\d\w]*)')
 
-    MIN_REGEX = 'min\(([^\)]+)\)'
+    MIN_REGEX = re.compile('min\(([^\)]+)\)')
 
-    OFFSET_REGEX = r"(?P<sign>[+-])(?P<intv>P.+)$"
+    OFFSET_REGEX = re.compile(r"(?P<sign>[+-])(?P<intv>P.+)$")
 
     TRUNCATED_REC_MAP = {"---": [re.compile("^\d\dT")],
                          "--": [re.compile("^\d\d\d\dT")],
@@ -108,47 +112,57 @@ class CylcTimeParser(object):
                                re.compile("W-\dT"),
                                re.compile("W-\d")]}
 
-    def __init__(self, context_start_point,
-                 context_end_point, num_expanded_year_digits=0,
-                 dump_format=None,
-                 assumed_time_zone=None):
+    __slots__ = ('timepoint_parser', 'duration_parser', 'recurrence_parser',
+                 'context_start_point', 'context_end_point')
+
+    def __init__(self, context_start_point, context_end_point, parsers):
         if context_start_point is not None:
             context_start_point = str(context_start_point)
         if context_end_point is not None:
             context_end_point = str(context_end_point)
-        self.num_expanded_year_digits = num_expanded_year_digits
+        self.timepoint_parser, self.duration_parser, self.recurrence_parser = (
+            parsers)
+
+        if isinstance(context_start_point, basestring):
+            context_start_point = self._get_point_from_expression(
+                context_start_point, None)[0]
+        self.context_start_point = context_start_point
+        if isinstance(context_end_point, basestring):
+            context_end_point = self._get_point_from_expression(
+                context_end_point, None)[0]
+        self.context_end_point = context_end_point
+
+    @staticmethod
+    def initiate_parsers(num_expanded_year_digits=0, dump_format=None,
+                         assumed_time_zone=None):
+        """Initiate datetime parsers required to initiate this class.
+
+        Returns:
+            tuple: (timepoint_parser, duration_parser, time_recurrence_parser)
+                - timepoint_parser - isodatetime.parsers.TimePointParser obj.
+                - duration_parser - isodatetime.parsers.DurationParser obj.
+                - time_recurrence_parser -
+                  isodatetime.parsers.TimeRecurrenceParser obj
+        """
+
         if dump_format is None:
             if num_expanded_year_digits:
                 dump_format = u"+XCCYYMMDDThhmmZ"
             else:
                 dump_format = "CCYYMMDDThhmmZ"
 
-        self.timepoint_parser = isodatetime.parsers.TimePointParser(
-            allow_only_basic=False,  # TODO - Ben: why was this set True
+        timepoint_parser = isodatetime.parsers.TimePointParser(
+            allow_only_basic=False,
             allow_truncated=True,
             num_expanded_year_digits=num_expanded_year_digits,
             dump_format=dump_format,
             assumed_time_zone=assumed_time_zone
         )
-        self._recur_format_recs = []
-        for regex, format_num in self.RECURRENCE_FORMAT_REGEXES:
-            self._recur_format_recs.append((re.compile(regex), format_num))
-        self._offset_rec = re.compile(self.OFFSET_REGEX)
-        self._invalid_point_recs = [
-            (re.compile(regex), msg) for (regex, msg) in
-            self.POINT_INVALID_FOR_CYLC_REGEXES
-        ]
-        if isinstance(context_start_point, basestring):
-            context_start_point, offset = self._get_point_from_expression(
-                context_start_point, None)
-        self.context_start_point = context_start_point
-        if isinstance(context_end_point, basestring):
-            context_end_point, offset = self._get_point_from_expression(
-                context_end_point, None)
-        self.context_end_point = context_end_point
-        self.duration_parser = isodatetime.parsers.DurationParser()
-        self.recurrence_parser = isodatetime.parsers.TimeRecurrenceParser(
-            timepoint_parser=self.timepoint_parser)
+
+        return (timepoint_parser,
+                isodatetime.parsers.DurationParser(),
+                isodatetime.parsers.TimeRecurrenceParser()
+                )
 
     def parse_interval(self, expr):
         """Parse an interval (duration) in full ISO date/time format."""
@@ -184,17 +198,17 @@ class CylcTimeParser(object):
                          context_start_point=None,
                          context_end_point=None):
         """Parse an expression in abbrev. or full ISO recurrence format."""
-        expression, exclusions = parse_exclusion(expression)
+        expression, exclusions = parse_exclusion(str(expression))
+
         if context_start_point is None:
             context_start_point = self.context_start_point
         if context_end_point is None:
             context_end_point = self.context_end_point
-        for rec_object, format_num in self._recur_format_recs:
+        for rec_object, format_num in self.RECURRENCE_FORMAT_REGEXES:
             result = rec_object.search(expression)
             if not result:
                 continue
 
-            props = {}
             repetitions = result.groupdict().get("reps")
             if repetitions is not None:
                 repetitions = int(repetitions)
@@ -223,13 +237,18 @@ class CylcTimeParser(object):
             # Convert the exclusion strings to ISO8601 points
             if exclusions is not None:
                 for exclusion in exclusions:
-                    exclusion_point, excl_off = (
-                        self._get_point_from_expression(
-                            exclusion, None, is_required=False,
-                            allow_truncated=False))
-                    if excl_off:
-                        exclusion_point += excl_off
-                    exclusion_points.append(exclusion_point)
+                    try:
+                        # Attempt to convert to TimePoint
+                        exclusion_point, excl_off = (
+                            self._get_point_from_expression(
+                                exclusion, None, is_required=False,
+                                allow_truncated=False))
+                        if excl_off:
+                            exclusion_point += excl_off
+                        exclusion_points.append(exclusion_point)
+                    except (CylcTimeSyntaxError, IndexError):
+                        # Not a point, parse it as recurrence later
+                        exclusion_points.append(exclusion)
 
             intv = result.groupdict().get("intv")
             intv_context_truncated_point = None
@@ -338,14 +357,14 @@ class CylcTimeParser(object):
         if expr.startswith("min("):
             expr = self._get_min_from_expression(expr, context)
 
-        if self._offset_rec.search(expr):
-            chain_expr = re.findall(self.CHAIN_REGEX, expr)
+        if self.OFFSET_REGEX.search(expr):
+            chain_expr = self.CHAIN_REGEX.findall(expr)
             expr = ""
             for item in chain_expr:
                 if "P" not in item:
                     expr += item
                     continue
-                split_expr = self._offset_rec.split(item)
+                split_expr = self.OFFSET_REGEX.split(item)
                 expr += split_expr.pop(0)
                 if split_expr[1] == "+":
                     split_expr.pop(1)
@@ -359,7 +378,7 @@ class CylcTimeParser(object):
                     expr_offset = expr_offset + expr_offset_item
         if not expr and allow_truncated:
             return context.copy(), expr_offset
-        for invalid_rec, msg in self._invalid_point_recs:
+        for invalid_rec, msg in self.POINT_INVALID_FOR_CYLC_REGEXES:
             if invalid_rec.search(expr):
                 raise CylcTimeSyntaxError("'%s': %s" % (expr, msg))
         expr_to_parse = expr
@@ -398,12 +417,16 @@ class TestRecurrenceSuite(unittest.TestCase):
         self._parsers = {
             0: CylcTimeParser(
                 self._start_point, self._end_point,
-                assumed_time_zone=UTC_UTC_OFFSET_HOURS_MINUTES
+                CylcTimeParser.initiate_parsers(
+                    assumed_time_zone=UTC_UTC_OFFSET_HOURS_MINUTES
+                )
             ),
             2: CylcTimeParser(
                 self._start_point, self._end_point,
-                num_expanded_year_digits=2,
-                assumed_time_zone=UTC_UTC_OFFSET_HOURS_MINUTES
+                CylcTimeParser.initiate_parsers(
+                    num_expanded_year_digits=2,
+                    assumed_time_zone=UTC_UTC_OFFSET_HOURS_MINUTES
+                )
             )
         }
 
@@ -435,7 +458,7 @@ class TestRecurrenceSuite(unittest.TestCase):
                 expression, num_expanded_year_digits, ctrl_data = test[:3]
                 ctrl_results = test[3]
             parser = self._parsers[num_expanded_year_digits]
-            recurrence, exclusion = parser.parse_recurrence(expression)
+            recurrence = parser.parse_recurrence(expression)[0]
             test_data = str(recurrence)
             self.assertEqual(test_data, ctrl_data)
             if ctrl_results is None:
@@ -487,8 +510,7 @@ class TestRecurrenceSuite(unittest.TestCase):
                 ctrl_results = None
             else:
                 expression, ctrl_data, ctrl_results = test
-            recurrence, exclusion = self._parsers[0].parse_recurrence(
-                expression)
+            recurrence = (self._parsers[0].parse_recurrence(expression))[0]
             test_data = str(recurrence)
             self.assertEqual(test_data, ctrl_data)
             if ctrl_results is None:
@@ -524,8 +546,8 @@ class TestRecurrenceSuite(unittest.TestCase):
                 ctrl_results = None
             else:
                 expression, ctrl_data, ctrl_results = test
-            recurrence, exclusion = self._parsers[0].parse_recurrence(
-                expression)
+            recurrence = (self._parsers[0].parse_recurrence(
+                expression))[0]
             test_data = str(recurrence)
             self.assertEqual(test_data, ctrl_data)
             if ctrl_results is None:
