@@ -3,7 +3,7 @@
 SUITE=$2
 
 # wait for task bar to fail
-cylc suite-state $SUITE --task=bar --cycle=1 \
+cylc suite-state $SUITE --task=bar --point=1 \
     --status=failed --max-polls=10 --interval=2
 
 # then remove it
